from ...symbols import NORM, ORTH

TOKENIZER_EXCEPTIONS = {
    ".ق ": [{ORTH: ".ق "}],
    ".م": [{ORTH: ".م"}],
    ".هـ": [{ORTH: ".هـ"}],
    "ب.م": [{ORTH: "ب.م"}],
    "ق.م": [{ORTH: "ق.م"}],
    "آبرویت": [{ORTH: "آبروی", NORM: "آبروی"}, {ORTH: "ت", NORM: "ت"}],
    "آب‌نباتش": [{ORTH: "آب‌نبات", NORM: "آب‌نبات"}, {ORTH: "ش", NORM: "ش"}],
    "آثارش": [{ORTH: "آثار", NORM: "آثار"}, {ORTH: "ش", NORM: "ش"}],
    "آخرش": [{ORTH: "آخر", NORM: "آخر"}, {ORTH: "ش", NORM: "ش"}],
    "آدمهاست": [{ORTH: "آدمها", NORM: "آدمها"}, {ORTH: "ست", NORM: "ست"}],
    "آرزومندیم": [{ORTH: "آرزومند", NORM: "آرزومند"}, {ORTH: "یم", NORM: "یم"}],
    "آزادند": [{ORTH: "آزاد", NORM: "آزاد"}, {ORTH: "ند", NORM: "ند"}],
    "آسیب‌پذیرند": [{ORTH: "آسیب‌پذیر", NORM: "آسیب‌پذیر"}, {ORTH: "ند", NORM: "ند"}],
    "آفریده‌اند": [{ORTH: "آفریده‌", NORM: "آفریده‌"}, {ORTH: "اند", NORM: "اند"}],
    "آمدنش": [{ORTH: "آمدن", NORM: "آمدن"}, {ORTH: "ش", NORM: "ش"}],
    "آمریکاست": [{ORTH: "آمریکا", NORM: "آمریکا"}, {ORTH: "ست", NORM: "ست"}],
    "آنجاست": [{ORTH: "آنجا", NORM: "آنجا"}, {ORTH: "ست", NORM: "ست"}],
    "آنست": [{ORTH: "آن", NORM: "آن"}, {ORTH: "ست", NORM: "ست"}],
    "آنند": [{ORTH: "آن", NORM: "آن"}, {ORTH: "ند", NORM: "ند"}],
    "آن‌هاست": [{ORTH: "آن‌ها", NORM: "آن‌ها"}, {ORTH: "ست", NORM: "ست"}],
    "آپاداناست": [{ORTH: "آپادانا", NORM: "آپادانا"}, {ORTH: "ست", NORM: "ست"}],
    "اجتماعی‌مان": [{ORTH: "اجتماعی‌", NORM: "اجتماعی‌"}, {ORTH: "مان", NORM: "مان"}],
    "اجدادت": [{ORTH: "اجداد", NORM: "اجداد"}, {ORTH: "ت", NORM: "ت"}],
    "اجدادش": [{ORTH: "اجداد", NORM: "اجداد"}, {ORTH: "ش", NORM: "ش"}],
    "اجدادی‌شان": [{ORTH: "اجدادی‌", NORM: "اجدادی‌"}, {ORTH: "شان", NORM: "شان"}],
    "اجراست": [{ORTH: "اجرا", NORM: "اجرا"}, {ORTH: "ست", NORM: "ست"}],
    "اختیارش": [{ORTH: "اختیار", NORM: "اختیار"}, {ORTH: "ش", NORM: "ش"}],
    "اخلاقشان": [{ORTH: "اخلاق", NORM: "اخلاق"}, {ORTH: "شان", NORM: "شان"}],
    "ادعایمان": [{ORTH: "ادعای", NORM: "ادعای"}, {ORTH: "مان", NORM: "مان"}],
    "اذیتش": [{ORTH: "اذیت", NORM: "اذیت"}, {ORTH: "ش", NORM: "ش"}],
    "اراده‌اش": [{ORTH: "اراده‌", NORM: "اراده‌"}, {ORTH: "اش", NORM: "اش"}],
    "ارتباطش": [{ORTH: "ارتباط", NORM: "ارتباط"}, {ORTH: "ش", NORM: "ش"}],
    "ارتباطمان": [{ORTH: "ارتباط", NORM: "ارتباط"}, {ORTH: "مان", NORM: "مان"}],
    "ارزشهاست": [{ORTH: "ارزشها", NORM: "ارزشها"}, {ORTH: "ست", NORM: "ست"}],
    "ارزی‌اش": [{ORTH: "ارزی‌", NORM: "ارزی‌"}, {ORTH: "اش", NORM: "اش"}],
    "اره‌اش": [{ORTH: "اره‌", NORM: "اره‌"}, {ORTH: "اش", NORM: "اش"}],
    "ازش": [{ORTH: "از", NORM: "از"}, {ORTH: "ش", NORM: "ش"}],
    "ازین": [{ORTH: "از", NORM: "از"}, {ORTH: "ین", NORM: "ین"}],
    "ازین‌هاست": [
        {ORTH: "از", NORM: "از"},
        {ORTH: "ین‌ها", NORM: "ین‌ها"},
        {ORTH: "ست", NORM: "ست"},
    ],
    "استخوانند": [{ORTH: "استخوان", NORM: "استخوان"}, {ORTH: "ند", NORM: "ند"}],
    "اسلامند": [{ORTH: "اسلام", NORM: "اسلام"}, {ORTH: "ند", NORM: "ند"}],
    "اسلامی‌اند": [{ORTH: "اسلامی‌", NORM: "اسلامی‌"}, {ORTH: "اند", NORM: "اند"}],
    "اسلحه‌هایشان": [
        {ORTH: "اسلحه‌های", NORM: "اسلحه‌های"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "اسمت": [{ORTH: "اسم", NORM: "اسم"}, {ORTH: "ت", NORM: "ت"}],
    "اسمش": [{ORTH: "اسم", NORM: "اسم"}, {ORTH: "ش", NORM: "ش"}],
    "اشتباهند": [{ORTH: "اشتباه", NORM: "اشتباه"}, {ORTH: "ند", NORM: "ند"}],
    "اصلش": [{ORTH: "اصل", NORM: "اصل"}, {ORTH: "ش", NORM: "ش"}],
    "اطاقش": [{ORTH: "اطاق", NORM: "اطاق"}, {ORTH: "ش", NORM: "ش"}],
    "اعتقادند": [{ORTH: "اعتقاد", NORM: "اعتقاد"}, {ORTH: "ند", NORM: "ند"}],
    "اعلایش": [{ORTH: "اعلای", NORM: "اعلای"}, {ORTH: "ش", NORM: "ش"}],
    "افتراست": [{ORTH: "افترا", NORM: "افترا"}, {ORTH: "ست", NORM: "ست"}],
    "افطارت": [{ORTH: "افطار", NORM: "افطار"}, {ORTH: "ت", NORM: "ت"}],
    "اقوامش": [{ORTH: "اقوام", NORM: "اقوام"}, {ORTH: "ش", NORM: "ش"}],
    "امروزیش": [{ORTH: "امروزی", NORM: "امروزی"}, {ORTH: "ش", NORM: "ش"}],
    "اموالش": [{ORTH: "اموال", NORM: "اموال"}, {ORTH: "ش", NORM: "ش"}],
    "امیدوارند": [{ORTH: "امیدوار", NORM: "امیدوار"}, {ORTH: "ند", NORM: "ند"}],
    "امیدواریم": [{ORTH: "امیدوار", NORM: "امیدوار"}, {ORTH: "یم", NORM: "یم"}],
    "انتخابهایم": [{ORTH: "انتخابها", NORM: "انتخابها"}, {ORTH: "یم", NORM: "یم"}],
    "انتظارم": [{ORTH: "انتظار", NORM: "انتظار"}, {ORTH: "م", NORM: "م"}],
    "انجمنم": [{ORTH: "انجمن", NORM: "انجمن"}, {ORTH: "م", NORM: "م"}],
    "اندرش": [{ORTH: "اندر", NORM: "اندر"}, {ORTH: "ش", NORM: "ش"}],
    "انشایش": [{ORTH: "انشای", NORM: "انشای"}, {ORTH: "ش", NORM: "ش"}],
    "انگشتشان": [{ORTH: "انگشت", NORM: "انگشت"}, {ORTH: "شان", NORM: "شان"}],
    "انگشتهایش": [{ORTH: "انگشتهای", NORM: "انگشتهای"}, {ORTH: "ش", NORM: "ش"}],
    "اهمیتشان": [{ORTH: "اهمیت", NORM: "اهمیت"}, {ORTH: "شان", NORM: "شان"}],
    "اهمیتند": [{ORTH: "اهمیت", NORM: "اهمیت"}, {ORTH: "ند", NORM: "ند"}],
    "اوایلش": [{ORTH: "اوایل", NORM: "اوایل"}, {ORTH: "ش", NORM: "ش"}],
    "اوست": [{ORTH: "او", NORM: "او"}, {ORTH: "ست", NORM: "ست"}],
    "اولش": [{ORTH: "اول", NORM: "اول"}, {ORTH: "ش", NORM: "ش"}],
    "اولشان": [{ORTH: "اول", NORM: "اول"}, {ORTH: "شان", NORM: "شان"}],
    "اولم": [{ORTH: "اول", NORM: "اول"}, {ORTH: "م", NORM: "م"}],
    "اکثرشان": [{ORTH: "اکثر", NORM: "اکثر"}, {ORTH: "شان", NORM: "شان"}],
    "ایتالیاست": [{ORTH: "ایتالیا", NORM: "ایتالیا"}, {ORTH: "ست", NORM: "ست"}],
    "ایرانی‌اش": [{ORTH: "ایرانی‌", NORM: "ایرانی‌"}, {ORTH: "اش", NORM: "اش"}],
    "اینجاست": [{ORTH: "اینجا", NORM: "اینجا"}, {ORTH: "ست", NORM: "ست"}],
    "این‌هاست": [{ORTH: "این‌ها", NORM: "این‌ها"}, {ORTH: "ست", NORM: "ست"}],
    "بابات": [{ORTH: "بابا", NORM: "بابا"}, {ORTH: "ت", NORM: "ت"}],
    "بارش": [{ORTH: "بار", NORM: "بار"}, {ORTH: "ش", NORM: "ش"}],
    "بازیگرانش": [{ORTH: "بازیگران", NORM: "بازیگران"}, {ORTH: "ش", NORM: "ش"}],
    "بازیگرمان": [{ORTH: "بازیگر", NORM: "بازیگر"}, {ORTH: "مان", NORM: "مان"}],
    "بازیگرهایم": [{ORTH: "بازیگرها", NORM: "بازیگرها"}, {ORTH: "یم", NORM: "یم"}],
    "بازی‌اش": [{ORTH: "بازی‌", NORM: "بازی‌"}, {ORTH: "اش", NORM: "اش"}],
    "بالاست": [{ORTH: "بالا", NORM: "بالا"}, {ORTH: "ست", NORM: "ست"}],
    "باورند": [{ORTH: "باور", NORM: "باور"}, {ORTH: "ند", NORM: "ند"}],
    "بجاست": [{ORTH: "بجا", NORM: "بجا"}, {ORTH: "ست", NORM: "ست"}],
    "بدان": [{ORTH: "ب", NORM: "ب"}, {ORTH: "دان", NORM: "دان"}],
    "بدش": [{ORTH: "بد", NORM: "بد"}, {ORTH: "ش", NORM: "ش"}],
    "بدشان": [{ORTH: "بد", NORM: "بد"}, {ORTH: "شان", NORM: "شان"}],
    "بدنم": [{ORTH: "بدن", NORM: "بدن"}, {ORTH: "م", NORM: "م"}],
    "بدهی‌ات": [{ORTH: "بدهی‌", NORM: "بدهی‌"}, {ORTH: "ات", NORM: "ات"}],
    "بدین": [{ORTH: "ب", NORM: "ب"}, {ORTH: "دین", NORM: "دین"}],
    "برابرش": [{ORTH: "برابر", NORM: "برابر"}, {ORTH: "ش", NORM: "ش"}],
    "برادرت": [{ORTH: "برادر", NORM: "برادر"}, {ORTH: "ت", NORM: "ت"}],
    "برادرش": [{ORTH: "برادر", NORM: "برادر"}, {ORTH: "ش", NORM: "ش"}],
    "برایت": [{ORTH: "برای", NORM: "برای"}, {ORTH: "ت", NORM: "ت"}],
    "برایتان": [{ORTH: "برای", NORM: "برای"}, {ORTH: "تان", NORM: "تان"}],
    "برایش": [{ORTH: "برای", NORM: "برای"}, {ORTH: "ش", NORM: "ش"}],
    "برایشان": [{ORTH: "برای", NORM: "برای"}, {ORTH: "شان", NORM: "شان"}],
    "برایم": [{ORTH: "برای", NORM: "برای"}, {ORTH: "م", NORM: "م"}],
    "برایمان": [{ORTH: "برای", NORM: "برای"}, {ORTH: "مان", NORM: "مان"}],
    "برخوردارند": [{ORTH: "برخوردار", NORM: "برخوردار"}, {ORTH: "ند", NORM: "ند"}],
    "برنامه‌سازهاست": [
        {ORTH: "برنامه‌سازها", NORM: "برنامه‌سازها"},
        {ORTH: "ست", NORM: "ست"},
    ],
    "برهمش": [{ORTH: "برهم", NORM: "برهم"}, {ORTH: "ش", NORM: "ش"}],
    "برهنه‌اش": [{ORTH: "برهنه‌", NORM: "برهنه‌"}, {ORTH: "اش", NORM: "اش"}],
    "برگهایش": [{ORTH: "برگها", NORM: "برگها"}, {ORTH: "یش", NORM: "یش"}],
    "برین": [{ORTH: "بر", NORM: "بر"}, {ORTH: "ین", NORM: "ین"}],
    "بزرگش": [{ORTH: "بزرگ", NORM: "بزرگ"}, {ORTH: "ش", NORM: "ش"}],
    "بزرگ‌تری": [{ORTH: "بزرگ‌تر", NORM: "بزرگ‌تر"}, {ORTH: "ی", NORM: "ی"}],
    "بساطش": [{ORTH: "بساط", NORM: "بساط"}, {ORTH: "ش", NORM: "ش"}],
    "بعدش": [{ORTH: "بعد", NORM: "بعد"}, {ORTH: "ش", NORM: "ش"}],
    "بعضیهایشان": [{ORTH: "بعضیهای", NORM: "بعضیهای"}, {ORTH: "شان", NORM: "شان"}],
    "بعضی‌شان": [{ORTH: "بعضی", NORM: "بعضی"}, {ORTH: "‌شان", NORM: "شان"}],
    "بقیه‌اش": [{ORTH: "بقیه‌", NORM: "بقیه‌"}, {ORTH: "اش", NORM: "اش"}],
    "بلندش": [{ORTH: "بلند", NORM: "بلند"}, {ORTH: "ش", NORM: "ش"}],
    "بناگوشش": [{ORTH: "بناگوش", NORM: "بناگوش"}, {ORTH: "ش", NORM: "ش"}],
    "بنظرم": [
        {ORTH: "ب", NORM: "ب"},
        {ORTH: "نظر", NORM: "نظر"},
        {ORTH: "م", NORM: "م"},
    ],
    "بهت": [{ORTH: "به", NORM: "به"}, {ORTH: "ت", NORM: "ت"}],
    "بهترش": [{ORTH: "بهتر", NORM: "بهتر"}, {ORTH: "ش", NORM: "ش"}],
    "بهترم": [{ORTH: "بهتر", NORM: "بهتر"}, {ORTH: "م", NORM: "م"}],
    "بهتری": [{ORTH: "بهتر", NORM: "بهتر"}, {ORTH: "ی", NORM: "ی"}],
    "بهش": [{ORTH: "به", NORM: "به"}, {ORTH: "ش", NORM: "ش"}],
    "به‌شان": [{ORTH: "به‌", NORM: "به‌"}, {ORTH: "شان", NORM: "شان"}],
    "بودمش": [{ORTH: "بودم", NORM: "بودم"}, {ORTH: "ش", NORM: "ش"}],
    "بودنش": [{ORTH: "بودن", NORM: "بودن"}, {ORTH: "ش", NORM: "ش"}],
    "بودن‌شان": [{ORTH: "بودن‌", NORM: "بودن‌"}, {ORTH: "شان", NORM: "شان"}],
    "بوستانش": [{ORTH: "بوستان", NORM: "بوستان"}, {ORTH: "ش", NORM: "ش"}],
    "بویش": [{ORTH: "بو", NORM: "بو"}, {ORTH: "یش", NORM: "یش"}],
    "بچه‌اش": [{ORTH: "بچه‌", NORM: "بچه‌"}, {ORTH: "اش", NORM: "اش"}],
    "بچه‌م": [{ORTH: "بچه‌", NORM: "بچه‌"}, {ORTH: "م", NORM: "م"}],
    "بچه‌هایش": [{ORTH: "بچه‌های", NORM: "بچه‌های"}, {ORTH: "ش", NORM: "ش"}],
    "بیانیه‌شان": [{ORTH: "بیانیه‌", NORM: "بیانیه‌"}, {ORTH: "شان", NORM: "شان"}],
    "بیدارم": [{ORTH: "بیدار", NORM: "بیدار"}, {ORTH: "م", NORM: "م"}],
    "بیناتری": [{ORTH: "بیناتر", NORM: "بیناتر"}, {ORTH: "ی", NORM: "ی"}],
    "بی‌اطلاعند": [{ORTH: "بی‌اطلاع", NORM: "بی‌اطلاع"}, {ORTH: "ند", NORM: "ند"}],
    "بی‌اطلاعید": [{ORTH: "بی‌اطلاع", NORM: "بی‌اطلاع"}, {ORTH: "ید", NORM: "ید"}],
    "بی‌بهره‌اند": [{ORTH: "بی‌بهره‌", NORM: "بی‌بهره‌"}, {ORTH: "اند", NORM: "اند"}],
    "بی‌تفاوتند": [{ORTH: "بی‌تفاوت", NORM: "بی‌تفاوت"}, {ORTH: "ند", NORM: "ند"}],
    "بی‌حسابش": [{ORTH: "بی‌حساب", NORM: "بی‌حساب"}, {ORTH: "ش", NORM: "ش"}],
    "بی‌نیش": [{ORTH: "بی‌نی", NORM: "بی‌نی"}, {ORTH: "ش", NORM: "ش"}],
    "تجربه‌هایم": [{ORTH: "تجربه‌ها", NORM: "تجربه‌ها"}, {ORTH: "یم", NORM: "یم"}],
    "تحریم‌هاست": [{ORTH: "تحریم‌ها", NORM: "تحریم‌ها"}, {ORTH: "ست", NORM: "ست"}],
    "تحولند": [{ORTH: "تحول", NORM: "تحول"}, {ORTH: "ند", NORM: "ند"}],
    "تخیلی‌اش": [{ORTH: "تخیلی‌", NORM: "تخیلی‌"}, {ORTH: "اش", NORM: "اش"}],
    "ترا": [{ORTH: "ت", NORM: "ت"}, {ORTH: "را", NORM: "را"}],
    "ترسشان": [{ORTH: "ترس", NORM: "ترس"}, {ORTH: "شان", NORM: "شان"}],
    "ترکش": [{ORTH: "ترک", NORM: "ترک"}, {ORTH: "ش", NORM: "ش"}],
    "تشنه‌ت": [{ORTH: "تشنه‌", NORM: "تشنه‌"}, {ORTH: "ت", NORM: "ت"}],
    "تشکیلاتی‌اش": [{ORTH: "تشکیلاتی‌", NORM: "تشکیلاتی‌"}, {ORTH: "اش", NORM: "اش"}],
    "تعلقش": [{ORTH: "تعلق", NORM: "تعلق"}, {ORTH: "ش", NORM: "ش"}],
    "تلاششان": [{ORTH: "تلاش", NORM: "تلاش"}, {ORTH: "شان", NORM: "شان"}],
    "تلاشمان": [{ORTH: "تلاش", NORM: "تلاش"}, {ORTH: "مان", NORM: "مان"}],
    "تماشاگرش": [{ORTH: "تماشاگر", NORM: "تماشاگر"}, {ORTH: "ش", NORM: "ش"}],
    "تمامشان": [{ORTH: "تمام", NORM: "تمام"}, {ORTH: "شان", NORM: "شان"}],
    "تنش": [{ORTH: "تن", NORM: "تن"}, {ORTH: "ش", NORM: "ش"}],
    "تنمان": [{ORTH: "تن", NORM: "تن"}, {ORTH: "مان", NORM: "مان"}],
    "تنهایی‌اش": [{ORTH: "تنهایی‌", NORM: "تنهایی‌"}, {ORTH: "اش", NORM: "اش"}],
    "توانایی‌اش": [{ORTH: "توانایی‌", NORM: "توانایی‌"}, {ORTH: "اش", NORM: "اش"}],
    "توجهش": [{ORTH: "توجه", NORM: "توجه"}, {ORTH: "ش", NORM: "ش"}],
    "توست": [{ORTH: "تو", NORM: "تو"}, {ORTH: "ست", NORM: "ست"}],
    "توصیه‌اش": [{ORTH: "توصیه‌", NORM: "توصیه‌"}, {ORTH: "اش", NORM: "اش"}],
    "تیغه‌اش": [{ORTH: "تیغه‌", NORM: "تیغه‌"}, {ORTH: "اش", NORM: "اش"}],
    "جاست": [{ORTH: "جا", NORM: "جا"}, {ORTH: "ست", NORM: "ست"}],
    "جامعه‌اند": [{ORTH: "جامعه‌", NORM: "جامعه‌"}, {ORTH: "اند", NORM: "اند"}],
    "جانم": [{ORTH: "جان", NORM: "جان"}, {ORTH: "م", NORM: "م"}],
    "جایش": [{ORTH: "جای", NORM: "جای"}, {ORTH: "ش", NORM: "ش"}],
    "جایشان": [{ORTH: "جای", NORM: "جای"}, {ORTH: "شان", NORM: "شان"}],
    "جدیدش": [{ORTH: "جدید", NORM: "جدید"}, {ORTH: "ش", NORM: "ش"}],
    "جرمزاست": [{ORTH: "جرمزا", NORM: "جرمزا"}, {ORTH: "ست", NORM: "ست"}],
    "جلوست": [{ORTH: "جلو", NORM: "جلو"}, {ORTH: "ست", NORM: "ست"}],
    "جلویش": [{ORTH: "جلوی", NORM: "جلوی"}, {ORTH: "ش", NORM: "ش"}],
    "جمهوریست": [{ORTH: "جمهوری", NORM: "جمهوری"}, {ORTH: "ست", NORM: "ست"}],
    "جنسش": [{ORTH: "جنس", NORM: "جنس"}, {ORTH: "ش", NORM: "ش"}],
    "جنس‌اند": [{ORTH: "جنس‌", NORM: "جنس‌"}, {ORTH: "اند", NORM: "اند"}],
    "جوانانش": [{ORTH: "جوانان", NORM: "جوانان"}, {ORTH: "ش", NORM: "ش"}],
    "جویش": [{ORTH: "جوی", NORM: "جوی"}, {ORTH: "ش", NORM: "ش"}],
    "جگرش": [{ORTH: "جگر", NORM: "جگر"}, {ORTH: "ش", NORM: "ش"}],
    "حاضرم": [{ORTH: "حاضر", NORM: "حاضر"}, {ORTH: "م", NORM: "م"}],
    "حالتهایشان": [{ORTH: "حالتهای", NORM: "حالتهای"}, {ORTH: "شان", NORM: "شان"}],
    "حالیست": [{ORTH: "حالی", NORM: "حالی"}, {ORTH: "ست", NORM: "ست"}],
    "حالی‌مان": [{ORTH: "حالی‌", NORM: "حالی‌"}, {ORTH: "مان", NORM: "مان"}],
    "حاکیست": [{ORTH: "حاکی", NORM: "حاکی"}, {ORTH: "ست", NORM: "ست"}],
    "حرامزادگی‌اش": [
        {ORTH: "حرامزادگی‌", NORM: "حرامزادگی‌"},
        {ORTH: "اش", NORM: "اش"},
    ],
    "حرفتان": [{ORTH: "حرف", NORM: "حرف"}, {ORTH: "تان", NORM: "تان"}],
    "حرفش": [{ORTH: "حرف", NORM: "حرف"}, {ORTH: "ش", NORM: "ش"}],
    "حرفشان": [{ORTH: "حرف", NORM: "حرف"}, {ORTH: "شان", NORM: "شان"}],
    "حرفم": [{ORTH: "حرف", NORM: "حرف"}, {ORTH: "م", NORM: "م"}],
    "حرف‌های‌شان": [{ORTH: "حرف‌های‌", NORM: "حرف‌های‌"}, {ORTH: "شان", NORM: "شان"}],
    "حرکتمان": [{ORTH: "حرکت", NORM: "حرکت"}, {ORTH: "مان", NORM: "مان"}],
    "حریفانشان": [{ORTH: "حریفان", NORM: "حریفان"}, {ORTH: "شان", NORM: "شان"}],
    "حضورشان": [{ORTH: "حضور", NORM: "حضور"}, {ORTH: "شان", NORM: "شان"}],
    "حمایتش": [{ORTH: "حمایت", NORM: "حمایت"}, {ORTH: "ش", NORM: "ش"}],
    "حواسش": [{ORTH: "حواس", NORM: "حواس"}, {ORTH: "ش", NORM: "ش"}],
    "حواسشان": [{ORTH: "حواس", NORM: "حواس"}, {ORTH: "شان", NORM: "شان"}],
    "حوصله‌مان": [{ORTH: "حوصله‌", NORM: "حوصله‌"}, {ORTH: "مان", NORM: "مان"}],
    "حکومتش": [{ORTH: "حکومت", NORM: "حکومت"}, {ORTH: "ش", NORM: "ش"}],
    "حکومتشان": [{ORTH: "حکومت", NORM: "حکومت"}, {ORTH: "شان", NORM: "شان"}],
    "حیفم": [{ORTH: "حیف", NORM: "حیف"}, {ORTH: "م", NORM: "م"}],
    "خاندانش": [{ORTH: "خاندان", NORM: "خاندان"}, {ORTH: "ش", NORM: "ش"}],
    "خانه‌اش": [{ORTH: "خانه‌", NORM: "خانه‌"}, {ORTH: "اش", NORM: "اش"}],
    "خانه‌شان": [{ORTH: "خانه‌", NORM: "خانه‌"}, {ORTH: "شان", NORM: "شان"}],
    "خانه‌مان": [{ORTH: "خانه‌", NORM: "خانه‌"}, {ORTH: "مان", NORM: "مان"}],
    "خانه‌هایشان": [{ORTH: "خانه‌های", NORM: "خانه‌های"}, {ORTH: "شان", NORM: "شان"}],
    "خانواده‌ات": [{ORTH: "خانواده", NORM: "خانواده"}, {ORTH: "‌ات", NORM: "ات"}],
    "خانواده‌اش": [{ORTH: "خانواده‌", NORM: "خانواده‌"}, {ORTH: "اش", NORM: "اش"}],
    "خانواده‌ام": [{ORTH: "خانواده‌", NORM: "خانواده‌"}, {ORTH: "ام", NORM: "ام"}],
    "خانواده‌شان": [{ORTH: "خانواده‌", NORM: "خانواده‌"}, {ORTH: "شان", NORM: "شان"}],
    "خداست": [{ORTH: "خدا", NORM: "خدا"}, {ORTH: "ست", NORM: "ست"}],
    "خدایش": [{ORTH: "خدا", NORM: "خدا"}, {ORTH: "یش", NORM: "یش"}],
    "خدایشان": [{ORTH: "خدای", NORM: "خدای"}, {ORTH: "شان", NORM: "شان"}],
    "خردسالش": [{ORTH: "خردسال", NORM: "خردسال"}, {ORTH: "ش", NORM: "ش"}],
    "خروپفشان": [{ORTH: "خروپف", NORM: "خروپف"}, {ORTH: "شان", NORM: "شان"}],
    "خسته‌ای": [{ORTH: "خسته‌", NORM: "خسته‌"}, {ORTH: "ای", NORM: "ای"}],
    "خطت": [{ORTH: "خط", NORM: "خط"}, {ORTH: "ت", NORM: "ت"}],
    "خوابمان": [{ORTH: "خواب", NORM: "خواب"}, {ORTH: "مان", NORM: "مان"}],
    "خواندنش": [{ORTH: "خواندن", NORM: "خواندن"}, {ORTH: "ش", NORM: "ش"}],
    "خواهرش": [{ORTH: "خواهر", NORM: "خواهر"}, {ORTH: "ش", NORM: "ش"}],
    "خوبش": [{ORTH: "خوب", NORM: "خوب"}, {ORTH: "ش", NORM: "ش"}],
    "خودت": [{ORTH: "خود", NORM: "خود"}, {ORTH: "ت", NORM: "ت"}],
    "خودتان": [{ORTH: "خود", NORM: "خود"}, {ORTH: "تان", NORM: "تان"}],
    "خودش": [{ORTH: "خود", NORM: "خود"}, {ORTH: "ش", NORM: "ش"}],
    "خودشان": [{ORTH: "خود", NORM: "خود"}, {ORTH: "شان", NORM: "شان"}],
    "خودمان": [{ORTH: "خود", NORM: "خود"}, {ORTH: "مان", NORM: "مان"}],
    "خوردمان": [{ORTH: "خورد", NORM: "خورد"}, {ORTH: "مان", NORM: "مان"}],
    "خوردنشان": [{ORTH: "خوردن", NORM: "خوردن"}, {ORTH: "شان", NORM: "شان"}],
    "خوشش": [{ORTH: "خوش", NORM: "خوش"}, {ORTH: "ش", NORM: "ش"}],
    "خوشوقتم": [{ORTH: "خوشوقت", NORM: "خوشوقت"}, {ORTH: "م", NORM: "م"}],
    "خونشان": [{ORTH: "خون", NORM: "خون"}, {ORTH: "شان", NORM: "شان"}],
    "خویش": [{ORTH: "خوی", NORM: "خوی"}, {ORTH: "ش", NORM: "ش"}],
    "خویشتنم": [{ORTH: "خویشتن", NORM: "خویشتن"}, {ORTH: "م", NORM: "م"}],
    "خیالش": [{ORTH: "خیال", NORM: "خیال"}, {ORTH: "ش", NORM: "ش"}],
    "خیسش": [{ORTH: "خیس", NORM: "خیس"}, {ORTH: "ش", NORM: "ش"}],
    "داراست": [{ORTH: "دارا", NORM: "دارا"}, {ORTH: "ست", NORM: "ست"}],
    "داستانهایش": [{ORTH: "داستانهای", NORM: "داستانهای"}, {ORTH: "ش", NORM: "ش"}],
    "دخترمان": [{ORTH: "دختر", NORM: "دختر"}, {ORTH: "مان", NORM: "مان"}],
    "دخیلند": [{ORTH: "دخیل", NORM: "دخیل"}, {ORTH: "ند", NORM: "ند"}],
    "درباره‌ات": [{ORTH: "درباره", NORM: "درباره"}, {ORTH: "‌ات", NORM: "ات"}],
    "درباره‌اش": [{ORTH: "درباره‌", NORM: "درباره‌"}, {ORTH: "اش", NORM: "اش"}],
    "دردش": [{ORTH: "درد", NORM: "درد"}, {ORTH: "ش", NORM: "ش"}],
    "دردشان": [{ORTH: "درد", NORM: "درد"}, {ORTH: "شان", NORM: "شان"}],
    "درسته": [{ORTH: "درست", NORM: "درست"}, {ORTH: "ه", NORM: "ه"}],
    "درش": [{ORTH: "در", NORM: "در"}, {ORTH: "ش", NORM: "ش"}],
    "درون‌شان": [{ORTH: "درون‌", NORM: "درون‌"}, {ORTH: "شان", NORM: "شان"}],
    "درین": [{ORTH: "در", NORM: "در"}, {ORTH: "ین", NORM: "ین"}],
    "دریچه‌هایش": [{ORTH: "دریچه‌های", NORM: "دریچه‌های"}, {ORTH: "ش", NORM: "ش"}],
    "دزدانش": [{ORTH: "دزدان", NORM: "دزدان"}, {ORTH: "ش", NORM: "ش"}],
    "دستت": [{ORTH: "دست", NORM: "دست"}, {ORTH: "ت", NORM: "ت"}],
    "دستش": [{ORTH: "دست", NORM: "دست"}, {ORTH: "ش", NORM: "ش"}],
    "دستمان": [{ORTH: "دست", NORM: "دست"}, {ORTH: "مان", NORM: "مان"}],
    "دستهایشان": [{ORTH: "دستهای", NORM: "دستهای"}, {ORTH: "شان", NORM: "شان"}],
    "دست‌یافتنی‌ست": [
        {ORTH: "دست‌یافتنی‌", NORM: "دست‌یافتنی‌"},
        {ORTH: "ست", NORM: "ست"},
    ],
    "دشمنند": [{ORTH: "دشمن", NORM: "دشمن"}, {ORTH: "ند", NORM: "ند"}],
    "دشمنیشان": [{ORTH: "دشمنی", NORM: "دشمنی"}, {ORTH: "شان", NORM: "شان"}],
    "دشمنیم": [{ORTH: "دشمن", NORM: "دشمن"}, {ORTH: "یم", NORM: "یم"}],
    "دفترش": [{ORTH: "دفتر", NORM: "دفتر"}, {ORTH: "ش", NORM: "ش"}],
    "دفنشان": [{ORTH: "دفن", NORM: "دفن"}, {ORTH: "شان", NORM: "شان"}],
    "دلت": [{ORTH: "دل", NORM: "دل"}, {ORTH: "ت", NORM: "ت"}],
    "دلش": [{ORTH: "دل", NORM: "دل"}, {ORTH: "ش", NORM: "ش"}],
    "دلشان": [{ORTH: "دل", NORM: "دل"}, {ORTH: "شان", NORM: "شان"}],
    "دلم": [{ORTH: "دل", NORM: "دل"}, {ORTH: "م", NORM: "م"}],
    "دلیلش": [{ORTH: "دلیل", NORM: "دلیل"}, {ORTH: "ش", NORM: "ش"}],
    "دنبالش": [{ORTH: "دنبال", NORM: "دنبال"}, {ORTH: "ش", NORM: "ش"}],
    "دنباله‌اش": [{ORTH: "دنباله‌", NORM: "دنباله‌"}, {ORTH: "اش", NORM: "اش"}],
    "دهاتی‌هایش": [{ORTH: "دهاتی‌های", NORM: "دهاتی‌های"}, {ORTH: "ش", NORM: "ش"}],
    "دهانت": [{ORTH: "دهان", NORM: "دهان"}, {ORTH: "ت", NORM: "ت"}],
    "دهنش": [{ORTH: "دهن", NORM: "دهن"}, {ORTH: "ش", NORM: "ش"}],
    "دورش": [{ORTH: "دور", NORM: "دور"}, {ORTH: "ش", NORM: "ش"}],
    "دوروبریهاشان": [
        {ORTH: "دوروبریها", NORM: "دوروبریها"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "دوستانش": [{ORTH: "دوستان", NORM: "دوستان"}, {ORTH: "ش", NORM: "ش"}],
    "دوستانشان": [{ORTH: "دوستان", NORM: "دوستان"}, {ORTH: "شان", NORM: "شان"}],
    "دوستت": [{ORTH: "دوست", NORM: "دوست"}, {ORTH: "ت", NORM: "ت"}],
    "دوستش": [{ORTH: "دوست", NORM: "دوست"}, {ORTH: "ش", NORM: "ش"}],
    "دومش": [{ORTH: "دوم", NORM: "دوم"}, {ORTH: "ش", NORM: "ش"}],
    "دویدنش": [{ORTH: "دویدن", NORM: "دویدن"}, {ORTH: "ش", NORM: "ش"}],
    "دکورهایمان": [{ORTH: "دکورهای", NORM: "دکورهای"}, {ORTH: "مان", NORM: "مان"}],
    "دیدگاهش": [{ORTH: "دیدگاه", NORM: "دیدگاه"}, {ORTH: "ش", NORM: "ش"}],
    "دیرت": [{ORTH: "دیر", NORM: "دیر"}, {ORTH: "ت", NORM: "ت"}],
    "دیرم": [{ORTH: "دیر", NORM: "دیر"}, {ORTH: "م", NORM: "م"}],
    "دینت": [{ORTH: "دین", NORM: "دین"}, {ORTH: "ت", NORM: "ت"}],
    "دینش": [{ORTH: "دین", NORM: "دین"}, {ORTH: "ش", NORM: "ش"}],
    "دین‌شان": [{ORTH: "دین‌", NORM: "دین‌"}, {ORTH: "شان", NORM: "شان"}],
    "دیواره‌هایش": [{ORTH: "دیواره‌های", NORM: "دیواره‌های"}, {ORTH: "ش", NORM: "ش"}],
    "دیوانه‌ای": [{ORTH: "دیوانه‌", NORM: "دیوانه‌"}, {ORTH: "ای", NORM: "ای"}],
    "دیوی": [{ORTH: "دیو", NORM: "دیو"}, {ORTH: "ی", NORM: "ی"}],
    "دیگرم": [{ORTH: "دیگر", NORM: "دیگر"}, {ORTH: "م", NORM: "م"}],
    "دیگرمان": [{ORTH: "دیگر", NORM: "دیگر"}, {ORTH: "مان", NORM: "مان"}],
    "ذهنش": [{ORTH: "ذهن", NORM: "ذهن"}, {ORTH: "ش", NORM: "ش"}],
    "ذهنشان": [{ORTH: "ذهن", NORM: "ذهن"}, {ORTH: "شان", NORM: "شان"}],
    "ذهنم": [{ORTH: "ذهن", NORM: "ذهن"}, {ORTH: "م", NORM: "م"}],
    "رئوسش": [{ORTH: "رئوس", NORM: "رئوس"}, {ORTH: "ش", NORM: "ش"}],
    "راهشان": [{ORTH: "راه", NORM: "راه"}, {ORTH: "شان", NORM: "شان"}],
    "راهگشاست": [{ORTH: "راهگشا", NORM: "راهگشا"}, {ORTH: "ست", NORM: "ست"}],
    "رایانه‌هایشان": [
        {ORTH: "رایانه‌های", NORM: "رایانه‌های"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "رعایتشان": [{ORTH: "رعایت", NORM: "رعایت"}, {ORTH: "شان", NORM: "شان"}],
    "رفتارش": [{ORTH: "رفتار", NORM: "رفتار"}, {ORTH: "ش", NORM: "ش"}],
    "رفتارشان": [{ORTH: "رفتار", NORM: "رفتار"}, {ORTH: "شان", NORM: "شان"}],
    "رفتارمان": [{ORTH: "رفتار", NORM: "رفتار"}, {ORTH: "مان", NORM: "مان"}],
    "رفتارهاست": [{ORTH: "رفتارها", NORM: "رفتارها"}, {ORTH: "ست", NORM: "ست"}],
    "رفتارهایشان": [{ORTH: "رفتارهای", NORM: "رفتارهای"}, {ORTH: "شان", NORM: "شان"}],
    "رفقایم": [{ORTH: "رفقا", NORM: "رفقا"}, {ORTH: "یم", NORM: "یم"}],
    "رقیق‌ترش": [{ORTH: "رقیق‌تر", NORM: "رقیق‌تر"}, {ORTH: "ش", NORM: "ش"}],
    "رنجند": [{ORTH: "رنج", NORM: "رنج"}, {ORTH: "ند", NORM: "ند"}],
    "رهگشاست": [{ORTH: "رهگشا", NORM: "رهگشا"}, {ORTH: "ست", NORM: "ست"}],
    "رواست": [{ORTH: "روا", NORM: "روا"}, {ORTH: "ست", NORM: "ست"}],
    "روبروست": [{ORTH: "روبرو", NORM: "روبرو"}, {ORTH: "ست", NORM: "ست"}],
    "روحی‌اش": [{ORTH: "روحی‌", NORM: "روحی‌"}, {ORTH: "اش", NORM: "اش"}],
    "روزنامه‌اش": [{ORTH: "روزنامه‌", NORM: "روزنامه‌"}, {ORTH: "اش", NORM: "اش"}],
    "روزه‌ست": [{ORTH: "روزه‌", NORM: "روزه‌"}, {ORTH: "ست", NORM: "ست"}],
    "روسری‌اش": [{ORTH: "روسری‌", NORM: "روسری‌"}, {ORTH: "اش", NORM: "اش"}],
    "روشتان": [{ORTH: "روش", NORM: "روش"}, {ORTH: "تان", NORM: "تان"}],
    "رویش": [{ORTH: "روی", NORM: "روی"}, {ORTH: "ش", NORM: "ش"}],
    "زبانش": [{ORTH: "زبان", NORM: "زبان"}, {ORTH: "ش", NORM: "ش"}],
    "زحماتشان": [{ORTH: "زحمات", NORM: "زحمات"}, {ORTH: "شان", NORM: "شان"}],
    "زدنهایشان": [{ORTH: "زدنهای", NORM: "زدنهای"}, {ORTH: "شان", NORM: "شان"}],
    "زرنگشان": [{ORTH: "زرنگ", NORM: "زرنگ"}, {ORTH: "شان", NORM: "شان"}],
    "زشتش": [{ORTH: "زشت", NORM: "زشت"}, {ORTH: "ش", NORM: "ش"}],
    "زشتکارانند": [{ORTH: "زشتکاران", NORM: "زشتکاران"}, {ORTH: "ند", NORM: "ند"}],
    "زلفش": [{ORTH: "زلف", NORM: "زلف"}, {ORTH: "ش", NORM: "ش"}],
    "زمن": [{ORTH: "ز", NORM: "ز"}, {ORTH: "من", NORM: "من"}],
    "زنبوری‌اش": [{ORTH: "زنبوری‌", NORM: "زنبوری‌"}, {ORTH: "اش", NORM: "اش"}],
    "زندانم": [{ORTH: "زندان", NORM: "زندان"}, {ORTH: "م", NORM: "م"}],
    "زنده‌ام": [{ORTH: "زنده‌", NORM: "زنده‌"}, {ORTH: "ام", NORM: "ام"}],
    "زندگانی‌اش": [{ORTH: "زندگانی‌", NORM: "زندگانی‌"}, {ORTH: "اش", NORM: "اش"}],
    "زندگی‌اش": [{ORTH: "زندگی‌", NORM: "زندگی‌"}, {ORTH: "اش", NORM: "اش"}],
    "زندگی‌ام": [{ORTH: "زندگی‌", NORM: "زندگی‌"}, {ORTH: "ام", NORM: "ام"}],
    "زندگی‌شان": [{ORTH: "زندگی‌", NORM: "زندگی‌"}, {ORTH: "شان", NORM: "شان"}],
    "زنش": [{ORTH: "زن", NORM: "زن"}, {ORTH: "ش", NORM: "ش"}],
    "زنند": [{ORTH: "زن", NORM: "زن"}, {ORTH: "ند", NORM: "ند"}],
    "زو": [{ORTH: "ز", NORM: "ز"}, {ORTH: "و", NORM: "و"}],
    "زیاده": [{ORTH: "زیاد", NORM: "زیاد"}, {ORTH: "ه", NORM: "ه"}],
    "زیباست": [{ORTH: "زیبا", NORM: "زیبا"}, {ORTH: "ست", NORM: "ست"}],
    "زیبایش": [{ORTH: "زیبای", NORM: "زیبای"}, {ORTH: "ش", NORM: "ش"}],
    "زیبایی": [{ORTH: "زیبای", NORM: "زیبای"}, {ORTH: "ی", NORM: "ی"}],
    "زیربناست": [{ORTH: "زیربنا", NORM: "زیربنا"}, {ORTH: "ست", NORM: "ست"}],
    "زیرک‌اند": [{ORTH: "زیرک‌", NORM: "زیرک‌"}, {ORTH: "اند", NORM: "اند"}],
    "سؤالتان": [{ORTH: "سؤال", NORM: "سؤال"}, {ORTH: "تان", NORM: "تان"}],
    "سؤالم": [{ORTH: "سؤال", NORM: "سؤال"}, {ORTH: "م", NORM: "م"}],
    "سابقه‌اش": [{ORTH: "سابقه‌", NORM: "سابقه‌"}, {ORTH: "اش", NORM: "اش"}],
    "ساختنم": [{ORTH: "ساختن", NORM: "ساختن"}, {ORTH: "م", NORM: "م"}],
    "ساده‌اش": [{ORTH: "ساده‌", NORM: "ساده‌"}, {ORTH: "اش", NORM: "اش"}],
    "ساده‌اند": [{ORTH: "ساده‌", NORM: "ساده‌"}, {ORTH: "اند", NORM: "اند"}],
    "سازمانش": [{ORTH: "سازمان", NORM: "سازمان"}, {ORTH: "ش", NORM: "ش"}],
    "ساعتم": [{ORTH: "ساعت", NORM: "ساعت"}, {ORTH: "م", NORM: "م"}],
    "سالته": [
        {ORTH: "سال", NORM: "سال"},
        {ORTH: "ت", NORM: "ت"},
        {ORTH: "ه", NORM: "ه"},
    ],
    "سالش": [{ORTH: "سال", NORM: "سال"}, {ORTH: "ش", NORM: "ش"}],
    "سالهاست": [{ORTH: "سالها", NORM: "سالها"}, {ORTH: "ست", NORM: "ست"}],
    "ساله‌اش": [{ORTH: "ساله‌", NORM: "ساله‌"}, {ORTH: "اش", NORM: "اش"}],
    "ساکتند": [{ORTH: "ساکت", NORM: "ساکت"}, {ORTH: "ند", NORM: "ند"}],
    "ساکنند": [{ORTH: "ساکن", NORM: "ساکن"}, {ORTH: "ند", NORM: "ند"}],
    "سبزشان": [{ORTH: "سبز", NORM: "سبز"}, {ORTH: "شان", NORM: "شان"}],
    "سبیل‌مان": [{ORTH: "سبیل‌", NORM: "سبیل‌"}, {ORTH: "مان", NORM: "مان"}],
    "ستم‌هایش": [{ORTH: "ستم‌های", NORM: "ستم‌های"}, {ORTH: "ش", NORM: "ش"}],
    "سخنانش": [{ORTH: "سخنان", NORM: "سخنان"}, {ORTH: "ش", NORM: "ش"}],
    "سخنانشان": [{ORTH: "سخنان", NORM: "سخنان"}, {ORTH: "شان", NORM: "شان"}],
    "سخنتان": [{ORTH: "سخن", NORM: "سخن"}, {ORTH: "تان", NORM: "تان"}],
    "سخنش": [{ORTH: "سخن", NORM: "سخن"}, {ORTH: "ش", NORM: "ش"}],
    "سخنم": [{ORTH: "سخن", NORM: "سخن"}, {ORTH: "م", NORM: "م"}],
    "سردش": [{ORTH: "سرد", NORM: "سرد"}, {ORTH: "ش", NORM: "ش"}],
    "سرزمینشان": [{ORTH: "سرزمین", NORM: "سرزمین"}, {ORTH: "شان", NORM: "شان"}],
    "سرش": [{ORTH: "سر", NORM: "سر"}, {ORTH: "ش", NORM: "ش"}],
    "سرمایه‌دارهاست": [
        {ORTH: "سرمایه‌دارها", NORM: "سرمایه‌دارها"},
        {ORTH: "ست", NORM: "ست"},
    ],
    "سرنوشتش": [{ORTH: "سرنوشت", NORM: "سرنوشت"}, {ORTH: "ش", NORM: "ش"}],
    "سرنوشتشان": [{ORTH: "سرنوشت", NORM: "سرنوشت"}, {ORTH: "شان", NORM: "شان"}],
    "سروتهش": [{ORTH: "سروته", NORM: "سروته"}, {ORTH: "ش", NORM: "ش"}],
    "سرچشمه‌اش": [{ORTH: "سرچشمه‌", NORM: "سرچشمه‌"}, {ORTH: "اش", NORM: "اش"}],
    "سقمش": [{ORTH: "سقم", NORM: "سقم"}, {ORTH: "ش", NORM: "ش"}],
    "سنش": [{ORTH: "سن", NORM: "سن"}, {ORTH: "ش", NORM: "ش"}],
    "سپاهش": [{ORTH: "سپاه", NORM: "سپاه"}, {ORTH: "ش", NORM: "ش"}],
    "سیاسیشان": [{ORTH: "سیاسی", NORM: "سیاسی"}, {ORTH: "شان", NORM: "شان"}],
    "سیاه‌چاله‌هاست": [
        {ORTH: "سیاه‌چاله‌ها", NORM: "سیاه‌چاله‌ها"},
        {ORTH: "ست", NORM: "ست"},
    ],
    "شاخه‌هایشان": [{ORTH: "شاخه‌های", NORM: "شاخه‌های"}, {ORTH: "شان", NORM: "شان"}],
    "شالوده‌اش": [{ORTH: "شالوده‌", NORM: "شالوده‌"}, {ORTH: "اش", NORM: "اش"}],
    "شانه‌هایش": [{ORTH: "شانه‌های", NORM: "شانه‌های"}, {ORTH: "ش", NORM: "ش"}],
    "شاهدیم": [{ORTH: "شاهد", NORM: "شاهد"}, {ORTH: "یم", NORM: "یم"}],
    "شاهکارهایش": [{ORTH: "شاهکارهای", NORM: "شاهکارهای"}, {ORTH: "ش", NORM: "ش"}],
    "شخصیتش": [{ORTH: "شخصیت", NORM: "شخصیت"}, {ORTH: "ش", NORM: "ش"}],
    "شدنشان": [{ORTH: "شدن", NORM: "شدن"}, {ORTH: "شان", NORM: "شان"}],
    "شرکتیست": [{ORTH: "شرکتی", NORM: "شرکتی"}, {ORTH: "ست", NORM: "ست"}],
    "شعارهاشان": [{ORTH: "شعارها", NORM: "شعارها"}, {ORTH: "شان", NORM: "شان"}],
    "شعورش": [{ORTH: "شعور", NORM: "شعور"}, {ORTH: "ش", NORM: "ش"}],
    "شغلش": [{ORTH: "شغل", NORM: "شغل"}, {ORTH: "ش", NORM: "ش"}],
    "شماست": [{ORTH: "شما", NORM: "شما"}, {ORTH: "ست", NORM: "ست"}],
    "شمشیرش": [{ORTH: "شمشیر", NORM: "شمشیر"}, {ORTH: "ش", NORM: "ش"}],
    "شنیدنش": [{ORTH: "شنیدن", NORM: "شنیدن"}, {ORTH: "ش", NORM: "ش"}],
    "شوراست": [{ORTH: "شورا", NORM: "شورا"}, {ORTH: "ست", NORM: "ست"}],
    "شومت": [{ORTH: "شوم", NORM: "شوم"}, {ORTH: "ت", NORM: "ت"}],
    "شیرینترش": [{ORTH: "شیرینتر", NORM: "شیرینتر"}, {ORTH: "ش", NORM: "ش"}],
    "شیطان‌اند": [{ORTH: "شیطان‌", NORM: "شیطان‌"}, {ORTH: "اند", NORM: "اند"}],
    "شیوه‌هاست": [{ORTH: "شیوه‌ها", NORM: "شیوه‌ها"}, {ORTH: "ست", NORM: "ست"}],
    "صاحبش": [{ORTH: "صاحب", NORM: "صاحب"}, {ORTH: "ش", NORM: "ش"}],
    "صحنه‌اش": [{ORTH: "صحنه‌", NORM: "صحنه‌"}, {ORTH: "اش", NORM: "اش"}],
    "صدایش": [{ORTH: "صدای", NORM: "صدای"}, {ORTH: "ش", NORM: "ش"}],
    "صددند": [{ORTH: "صدد", NORM: "صدد"}, {ORTH: "ند", NORM: "ند"}],
    "صندوق‌هاست": [{ORTH: "صندوق‌ها", NORM: "صندوق‌ها"}, {ORTH: "ست", NORM: "ست"}],
    "صندوق‌هایش": [{ORTH: "صندوق‌های", NORM: "صندوق‌های"}, {ORTH: "ش", NORM: "ش"}],
    "صورتش": [{ORTH: "صورت", NORM: "صورت"}, {ORTH: "ش", NORM: "ش"}],
    "ضروری‌اند": [{ORTH: "ضروری‌", NORM: "ضروری‌"}, {ORTH: "اند", NORM: "اند"}],
    "ضمیرش": [{ORTH: "ضمیر", NORM: "ضمیر"}, {ORTH: "ش", NORM: "ش"}],
    "طرفش": [{ORTH: "طرف", NORM: "طرف"}, {ORTH: "ش", NORM: "ش"}],
    "طلسمش": [{ORTH: "طلسم", NORM: "طلسم"}, {ORTH: "ش", NORM: "ش"}],
    "طوره": [{ORTH: "طور", NORM: "طور"}, {ORTH: "ه", NORM: "ه"}],
    "عاشوراست": [{ORTH: "عاشورا", NORM: "عاشورا"}, {ORTH: "ست", NORM: "ست"}],
    "عبارتند": [{ORTH: "عبارت", NORM: "عبارت"}, {ORTH: "ند", NORM: "ند"}],
    "عزیزانتان": [{ORTH: "عزیزان", NORM: "عزیزان"}, {ORTH: "تان", NORM: "تان"}],
    "عزیزانش": [{ORTH: "عزیزان", NORM: "عزیزان"}, {ORTH: "ش", NORM: "ش"}],
    "عزیزش": [{ORTH: "عزیز", NORM: "عزیز"}, {ORTH: "ش", NORM: "ش"}],
    "عشرت‌طلبی‌اش": [
        {ORTH: "عشرت‌طلبی‌", NORM: "عشرت‌طلبی‌"},
        {ORTH: "اش", NORM: "اش"},
    ],
    "عقبیم": [{ORTH: "عقب", NORM: "عقب"}, {ORTH: "یم", NORM: "یم"}],
    "علاقه‌اش": [{ORTH: "علاقه‌", NORM: "علاقه‌"}, {ORTH: "اش", NORM: "اش"}],
    "علمیمان": [{ORTH: "علمی", NORM: "علمی"}, {ORTH: "مان", NORM: "مان"}],
    "عمرش": [{ORTH: "عمر", NORM: "عمر"}, {ORTH: "ش", NORM: "ش"}],
    "عمرشان": [{ORTH: "عمر", NORM: "عمر"}, {ORTH: "شان", NORM: "شان"}],
    "عملش": [{ORTH: "عمل", NORM: "عمل"}, {ORTH: "ش", NORM: "ش"}],
    "عملی‌اند": [{ORTH: "عملی‌", NORM: "عملی‌"}, {ORTH: "اند", NORM: "اند"}],
    "عمویت": [{ORTH: "عموی", NORM: "عموی"}, {ORTH: "ت", NORM: "ت"}],
    "عمویش": [{ORTH: "عموی", NORM: "عموی"}, {ORTH: "ش", NORM: "ش"}],
    "عمیقش": [{ORTH: "عمیق", NORM: "عمیق"}, {ORTH: "ش", NORM: "ش"}],
    "عواملش": [{ORTH: "عوامل", NORM: "عوامل"}, {ORTH: "ش", NORM: "ش"}],
    "عوضشان": [{ORTH: "عوض", NORM: "عوض"}, {ORTH: "شان", NORM: "شان"}],
    "غذایی‌شان": [{ORTH: "غذایی‌", NORM: "غذایی‌"}, {ORTH: "شان", NORM: "شان"}],
    "غریبه‌اند": [{ORTH: "غریبه‌", NORM: "غریبه‌"}, {ORTH: "اند", NORM: "اند"}],
    "غلامانش": [{ORTH: "غلامان", NORM: "غلامان"}, {ORTH: "ش", NORM: "ش"}],
    "غلطهاست": [{ORTH: "غلطها", NORM: "غلطها"}, {ORTH: "ست", NORM: "ست"}],
    "فراموشتان": [{ORTH: "فراموش", NORM: "فراموش"}, {ORTH: "تان", NORM: "تان"}],
    "فردی‌اند": [{ORTH: "فردی‌", NORM: "فردی‌"}, {ORTH: "اند", NORM: "اند"}],
    "فرزندانش": [{ORTH: "فرزندان", NORM: "فرزندان"}, {ORTH: "ش", NORM: "ش"}],
    "فرزندش": [{ORTH: "فرزند", NORM: "فرزند"}, {ORTH: "ش", NORM: "ش"}],
    "فرم‌هایش": [{ORTH: "فرم‌های", NORM: "فرم‌های"}, {ORTH: "ش", NORM: "ش"}],
    "فرهنگی‌مان": [{ORTH: "فرهنگی‌", NORM: "فرهنگی‌"}, {ORTH: "مان", NORM: "مان"}],
    "فریادشان": [{ORTH: "فریاد", NORM: "فریاد"}, {ORTH: "شان", NORM: "شان"}],
    "فضایی‌شان": [{ORTH: "فضایی‌", NORM: "فضایی‌"}, {ORTH: "شان", NORM: "شان"}],
    "فقیرشان": [{ORTH: "فقیر", NORM: "فقیر"}, {ORTH: "شان", NORM: "شان"}],
    "فوری‌شان": [{ORTH: "فوری‌", NORM: "فوری‌"}, {ORTH: "شان", NORM: "شان"}],
    "قائلند": [{ORTH: "قائل", NORM: "قائل"}, {ORTH: "ند", NORM: "ند"}],
    "قائلیم": [{ORTH: "قائل", NORM: "قائل"}, {ORTH: "یم", NORM: "یم"}],
    "قادرند": [{ORTH: "قادر", NORM: "قادر"}, {ORTH: "ند", NORM: "ند"}],
    "قانونمندش": [{ORTH: "قانونمند", NORM: "قانونمند"}, {ORTH: "ش", NORM: "ش"}],
    "قبلند": [{ORTH: "قبل", NORM: "قبل"}, {ORTH: "ند", NORM: "ند"}],
    "قبلی‌اش": [{ORTH: "قبلی‌", NORM: "قبلی‌"}, {ORTH: "اش", NORM: "اش"}],
    "قبلی‌مان": [{ORTH: "قبلی‌", NORM: "قبلی‌"}, {ORTH: "مان", NORM: "مان"}],
    "قدریست": [{ORTH: "قدری", NORM: "قدری"}, {ORTH: "ست", NORM: "ست"}],
    "قدمش": [{ORTH: "قدم", NORM: "قدم"}, {ORTH: "ش", NORM: "ش"}],
    "قسمتش": [{ORTH: "قسمت", NORM: "قسمت"}, {ORTH: "ش", NORM: "ش"}],
    "قضایاست": [{ORTH: "قضایا", NORM: "قضایا"}, {ORTH: "ست", NORM: "ست"}],
    "قضیه‌شان": [{ORTH: "قضیه‌", NORM: "قضیه‌"}, {ORTH: "شان", NORM: "شان"}],
    "قهرمانهایشان": [
        {ORTH: "قهرمانهای", NORM: "قهرمانهای"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "قهرمانیش": [{ORTH: "قهرمانی", NORM: "قهرمانی"}, {ORTH: "ش", NORM: "ش"}],
    "قومت": [{ORTH: "قوم", NORM: "قوم"}, {ORTH: "ت", NORM: "ت"}],
    "لازمه‌اش": [{ORTH: "لازمه‌", NORM: "لازمه‌"}, {ORTH: "اش", NORM: "اش"}],
    "مأموریتش": [{ORTH: "مأموریت", NORM: "مأموریت"}, {ORTH: "ش", NORM: "ش"}],
    "مأموریتم": [{ORTH: "مأموریت", NORM: "مأموریت"}, {ORTH: "م", NORM: "م"}],
    "مأموریت‌اند": [{ORTH: "مأموریت‌", NORM: "مأموریت‌"}, {ORTH: "اند", NORM: "اند"}],
    "مادرانشان": [{ORTH: "مادران", NORM: "مادران"}, {ORTH: "شان", NORM: "شان"}],
    "مادرت": [{ORTH: "مادر", NORM: "مادر"}, {ORTH: "ت", NORM: "ت"}],
    "مادرش": [{ORTH: "مادر", NORM: "مادر"}, {ORTH: "ش", NORM: "ش"}],
    "مادرم": [{ORTH: "مادر", NORM: "مادر"}, {ORTH: "م", NORM: "م"}],
    "ماست": [{ORTH: "ما", NORM: "ما"}, {ORTH: "ست", NORM: "ست"}],
    "مالی‌اش": [{ORTH: "مالی‌", NORM: "مالی‌"}, {ORTH: "اش", NORM: "اش"}],
    "ماهیتش": [{ORTH: "ماهیت", NORM: "ماهیت"}, {ORTH: "ش", NORM: "ش"}],
    "مایی": [{ORTH: "ما", NORM: "ما"}, {ORTH: "یی", NORM: "یی"}],
    "مجازاتش": [{ORTH: "مجازات", NORM: "مجازات"}, {ORTH: "ش", NORM: "ش"}],
    "مجبورند": [{ORTH: "مجبور", NORM: "مجبور"}, {ORTH: "ند", NORM: "ند"}],
    "محتاجند": [{ORTH: "محتاج", NORM: "محتاج"}, {ORTH: "ند", NORM: "ند"}],
    "محرمم": [{ORTH: "محرم", NORM: "محرم"}, {ORTH: "م", NORM: "م"}],
    "محلش": [{ORTH: "محل", NORM: "محل"}, {ORTH: "ش", NORM: "ش"}],
    "مخالفند": [{ORTH: "مخالف", NORM: "مخالف"}, {ORTH: "ند", NORM: "ند"}],
    "مخدرش": [{ORTH: "مخدر", NORM: "مخدر"}, {ORTH: "ش", NORM: "ش"}],
    "مدتهاست": [{ORTH: "مدتها", NORM: "مدتها"}, {ORTH: "ست", NORM: "ست"}],
    "مدرسه‌ات": [{ORTH: "مدرسه", NORM: "مدرسه"}, {ORTH: "‌ات", NORM: "ات"}],
    "مدرکم": [{ORTH: "مدرک", NORM: "مدرک"}, {ORTH: "م", NORM: "م"}],
    "مدیرانش": [{ORTH: "مدیران", NORM: "مدیران"}, {ORTH: "ش", NORM: "ش"}],
    "مدیونم": [{ORTH: "مدیون", NORM: "مدیون"}, {ORTH: "م", NORM: "م"}],
    "مذهبی‌اند": [{ORTH: "مذهبی‌", NORM: "مذهبی‌"}, {ORTH: "اند", NORM: "اند"}],
    "مرا": [{ORTH: "م", NORM: "م"}, {ORTH: "را", NORM: "را"}],
    "مرادت": [{ORTH: "مراد", NORM: "مراد"}, {ORTH: "ت", NORM: "ت"}],
    "مردمشان": [{ORTH: "مردم", NORM: "مردم"}, {ORTH: "شان", NORM: "شان"}],
    "مردمند": [{ORTH: "مردم", NORM: "مردم"}, {ORTH: "ند", NORM: "ند"}],
    "مردم‌اند": [{ORTH: "مردم‌", NORM: "مردم‌"}, {ORTH: "اند", NORM: "اند"}],
    "مرزشان": [{ORTH: "مرز", NORM: "مرز"}, {ORTH: "شان", NORM: "شان"}],
    "مرزهاشان": [{ORTH: "مرزها", NORM: "مرزها"}, {ORTH: "شان", NORM: "شان"}],
    "مزدورش": [{ORTH: "مزدور", NORM: "مزدور"}, {ORTH: "ش", NORM: "ش"}],
    "مسئولیتش": [{ORTH: "مسئولیت", NORM: "مسئولیت"}, {ORTH: "ش", NORM: "ش"}],
    "مسائلش": [{ORTH: "مسائل", NORM: "مسائل"}, {ORTH: "ش", NORM: "ش"}],
    "مستحضرید": [{ORTH: "مستحضر", NORM: "مستحضر"}, {ORTH: "ید", NORM: "ید"}],
    "مسلمانم": [{ORTH: "مسلمان", NORM: "مسلمان"}, {ORTH: "م", NORM: "م"}],
    "مسلمانند": [{ORTH: "مسلمان", NORM: "مسلمان"}, {ORTH: "ند", NORM: "ند"}],
    "مشتریانش": [{ORTH: "مشتریان", NORM: "مشتریان"}, {ORTH: "ش", NORM: "ش"}],
    "مشتهایمان": [{ORTH: "مشتهای", NORM: "مشتهای"}, {ORTH: "مان", NORM: "مان"}],
    "مشخصند": [{ORTH: "مشخص", NORM: "مشخص"}, {ORTH: "ند", NORM: "ند"}],
    "مشغولند": [{ORTH: "مشغول", NORM: "مشغول"}, {ORTH: "ند", NORM: "ند"}],
    "مشغولیم": [{ORTH: "مشغول", NORM: "مشغول"}, {ORTH: "یم", NORM: "یم"}],
    "مشهورش": [{ORTH: "مشهور", NORM: "مشهور"}, {ORTH: "ش", NORM: "ش"}],
    "مشکلاتشان": [{ORTH: "مشکلات", NORM: "مشکلات"}, {ORTH: "شان", NORM: "شان"}],
    "مشکلم": [{ORTH: "مشکل", NORM: "مشکل"}, {ORTH: "م", NORM: "م"}],
    "مطمئنم": [{ORTH: "مطمئن", NORM: "مطمئن"}, {ORTH: "م", NORM: "م"}],
    "معامله‌مان": [{ORTH: "معامله‌", NORM: "معامله‌"}, {ORTH: "مان", NORM: "مان"}],
    "معتقدم": [{ORTH: "معتقد", NORM: "معتقد"}, {ORTH: "م", NORM: "م"}],
    "معتقدند": [{ORTH: "معتقد", NORM: "معتقد"}, {ORTH: "ند", NORM: "ند"}],
    "معتقدیم": [{ORTH: "معتقد", NORM: "معتقد"}, {ORTH: "یم", NORM: "یم"}],
    "معرفی‌اش": [{ORTH: "معرفی‌", NORM: "معرفی‌"}, {ORTH: "اش", NORM: "اش"}],
    "معروفش": [{ORTH: "معروف", NORM: "معروف"}, {ORTH: "ش", NORM: "ش"}],
    "معضلاتمان": [{ORTH: "معضلات", NORM: "معضلات"}, {ORTH: "مان", NORM: "مان"}],
    "معلمش": [{ORTH: "معلم", NORM: "معلم"}, {ORTH: "ش", NORM: "ش"}],
    "معنایش": [{ORTH: "معنای", NORM: "معنای"}, {ORTH: "ش", NORM: "ش"}],
    "مغزشان": [{ORTH: "مغز", NORM: "مغز"}, {ORTH: "شان", NORM: "شان"}],
    "مفیدند": [{ORTH: "مفید", NORM: "مفید"}, {ORTH: "ند", NORM: "ند"}],
    "مقابلش": [{ORTH: "مقابل", NORM: "مقابل"}, {ORTH: "ش", NORM: "ش"}],
    "مقاله‌اش": [{ORTH: "مقاله‌", NORM: "مقاله‌"}, {ORTH: "اش", NORM: "اش"}],
    "مقدمش": [{ORTH: "مقدم", NORM: "مقدم"}, {ORTH: "ش", NORM: "ش"}],
    "مقرش": [{ORTH: "مقر", NORM: "مقر"}, {ORTH: "ش", NORM: "ش"}],
    "مقصدشان": [{ORTH: "مقصد", NORM: "مقصد"}, {ORTH: "شان", NORM: "شان"}],
    "مقصرند": [{ORTH: "مقصر", NORM: "مقصر"}, {ORTH: "ند", NORM: "ند"}],
    "مقصودتان": [{ORTH: "مقصود", NORM: "مقصود"}, {ORTH: "تان", NORM: "تان"}],
    "ملاقاتهایش": [{ORTH: "ملاقاتهای", NORM: "ملاقاتهای"}, {ORTH: "ش", NORM: "ش"}],
    "ممکنشان": [{ORTH: "ممکن", NORM: "ممکن"}, {ORTH: "شان", NORM: "شان"}],
    "ممیزیهاست": [{ORTH: "ممیزیها", NORM: "ممیزیها"}, {ORTH: "ست", NORM: "ست"}],
    "منظورم": [{ORTH: "منظور", NORM: "منظور"}, {ORTH: "م", NORM: "م"}],
    "منی": [{ORTH: "من", NORM: "من"}, {ORTH: "ی", NORM: "ی"}],
    "منید": [{ORTH: "من", NORM: "من"}, {ORTH: "ید", NORM: "ید"}],
    "مهربانش": [{ORTH: "مهربان", NORM: "مهربان"}, {ORTH: "ش", NORM: "ش"}],
    "مهم‌اند": [{ORTH: "مهم‌", NORM: "مهم‌"}, {ORTH: "اند", NORM: "اند"}],
    "مواجهند": [{ORTH: "مواجه", NORM: "مواجه"}, {ORTH: "ند", NORM: "ند"}],
    "مواجه‌اند": [{ORTH: "مواجه‌", NORM: "مواجه‌"}, {ORTH: "اند", NORM: "اند"}],
    "مواخذه‌ات": [{ORTH: "مواخذه", NORM: "مواخذه"}, {ORTH: "‌ات", NORM: "ات"}],
    "مواضعشان": [{ORTH: "مواضع", NORM: "مواضع"}, {ORTH: "شان", NORM: "شان"}],
    "مواضعمان": [{ORTH: "مواضع", NORM: "مواضع"}, {ORTH: "مان", NORM: "مان"}],
    "موافقند": [{ORTH: "موافق", NORM: "موافق"}, {ORTH: "ند", NORM: "ند"}],
    "موجوداتش": [{ORTH: "موجودات", NORM: "موجودات"}, {ORTH: "ش", NORM: "ش"}],
    "موجودند": [{ORTH: "موجود", NORM: "موجود"}, {ORTH: "ند", NORM: "ند"}],
    "موردش": [{ORTH: "مورد", NORM: "مورد"}, {ORTH: "ش", NORM: "ش"}],
    "موضعشان": [{ORTH: "موضع", NORM: "موضع"}, {ORTH: "شان", NORM: "شان"}],
    "موظفند": [{ORTH: "موظف", NORM: "موظف"}, {ORTH: "ند", NORM: "ند"}],
    "موهایش": [{ORTH: "موهای", NORM: "موهای"}, {ORTH: "ش", NORM: "ش"}],
    "موهایمان": [{ORTH: "موهای", NORM: "موهای"}, {ORTH: "مان", NORM: "مان"}],
    "مویم": [{ORTH: "مو", NORM: "مو"}, {ORTH: "یم", NORM: "یم"}],
    "ناخرسندند": [{ORTH: "ناخرسند", NORM: "ناخرسند"}, {ORTH: "ند", NORM: "ند"}],
    "ناراحتیش": [{ORTH: "ناراحتی", NORM: "ناراحتی"}, {ORTH: "ش", NORM: "ش"}],
    "ناراضی‌اند": [{ORTH: "ناراضی‌", NORM: "ناراضی‌"}, {ORTH: "اند", NORM: "اند"}],
    "نارواست": [{ORTH: "ناروا", NORM: "ناروا"}, {ORTH: "ست", NORM: "ست"}],
    "نازش": [{ORTH: "ناز", NORM: "ناز"}, {ORTH: "ش", NORM: "ش"}],
    "نامش": [{ORTH: "نام", NORM: "نام"}, {ORTH: "ش", NORM: "ش"}],
    "نامشان": [{ORTH: "نام", NORM: "نام"}, {ORTH: "شان", NORM: "شان"}],
    "نامم": [{ORTH: "نام", NORM: "نام"}, {ORTH: "م", NORM: "م"}],
    "نامه‌ات": [{ORTH: "نامه", NORM: "نامه"}, {ORTH: "‌ات", NORM: "ات"}],
    "نامه‌ام": [{ORTH: "نامه‌", NORM: "نامه‌"}, {ORTH: "ام", NORM: "ام"}],
    "ناچارم": [{ORTH: "ناچار", NORM: "ناچار"}, {ORTH: "م", NORM: "م"}],
    "نخست‌وزیری‌اش": [
        {ORTH: "نخست‌وزیری‌", NORM: "نخست‌وزیری‌"},
        {ORTH: "اش", NORM: "اش"},
    ],
    "نزدش": [{ORTH: "نزد", NORM: "نزد"}, {ORTH: "ش", NORM: "ش"}],
    "نشانم": [{ORTH: "نشان", NORM: "نشان"}, {ORTH: "م", NORM: "م"}],
    "نظرات‌شان": [{ORTH: "نظرات‌", NORM: "نظرات‌"}, {ORTH: "شان", NORM: "شان"}],
    "نظرتان": [{ORTH: "نظر", NORM: "نظر"}, {ORTH: "تان", NORM: "تان"}],
    "نظرش": [{ORTH: "نظر", NORM: "نظر"}, {ORTH: "ش", NORM: "ش"}],
    "نظرشان": [{ORTH: "نظر", NORM: "نظر"}, {ORTH: "شان", NORM: "شان"}],
    "نظرم": [{ORTH: "نظر", NORM: "نظر"}, {ORTH: "م", NORM: "م"}],
    "نظرهایشان": [{ORTH: "نظرهای", NORM: "نظرهای"}, {ORTH: "شان", NORM: "شان"}],
    "نفاقش": [{ORTH: "نفاق", NORM: "نفاق"}, {ORTH: "ش", NORM: "ش"}],
    "نفرند": [{ORTH: "نفر", NORM: "نفر"}, {ORTH: "ند", NORM: "ند"}],
    "نفوذیند": [{ORTH: "نفوذی", NORM: "نفوذی"}, {ORTH: "ند", NORM: "ند"}],
    "نقطه‌نظراتتان": [
        {ORTH: "نقطه‌نظرات", NORM: "نقطه‌نظرات"},
        {ORTH: "تان", NORM: "تان"},
    ],
    "نمایشی‌مان": [{ORTH: "نمایشی‌", NORM: "نمایشی‌"}, {ORTH: "مان", NORM: "مان"}],
    "نمایندگی‌شان": [
        {ORTH: "نمایندگی‌", NORM: "نمایندگی‌"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "نمونه‌اش": [{ORTH: "نمونه‌", NORM: "نمونه‌"}, {ORTH: "اش", NORM: "اش"}],
    "نمی‌پذیرندش": [{ORTH: "نمی‌پذیرند", NORM: "نمی‌پذیرند"}, {ORTH: "ش", NORM: "ش"}],
    "نوآوری‌اش": [{ORTH: "نوآوری‌", NORM: "نوآوری‌"}, {ORTH: "اش", NORM: "اش"}],
    "نوشته‌هایشان": [
        {ORTH: "نوشته‌های", NORM: "نوشته‌های"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "نوشته‌هایم": [{ORTH: "نوشته‌ها", NORM: "نوشته‌ها"}, {ORTH: "یم", NORM: "یم"}],
    "نکردنشان": [{ORTH: "نکردن", NORM: "نکردن"}, {ORTH: "شان", NORM: "شان"}],
    "نگاهداری‌شان": [
        {ORTH: "نگاهداری‌", NORM: "نگاهداری‌"},
        {ORTH: "شان", NORM: "شان"},
    ],
    "نگاهش": [{ORTH: "نگاه", NORM: "نگاه"}, {ORTH: "ش", NORM: "ش"}],
    "نگرانم": [{ORTH: "نگران", NORM: "نگران"}, {ORTH: "م", NORM: "م"}],
    "نگرشهایشان": [{ORTH: "نگرشهای", NORM: "نگرشهای"}, {ORTH: "شان", NORM: "شان"}],
    "نیازمندند": [{ORTH: "نیازمند", NORM: "نیازمند"}, {ORTH: "ند", NORM: "ند"}],
    "هدفش": [{ORTH: "هدف", NORM: "هدف"}, {ORTH: "ش", NORM: "ش"}],
    "همانست": [{ORTH: "همان", NORM: "همان"}, {ORTH: "ست", NORM: "ست"}],
    "همراهش": [{ORTH: "همراه", NORM: "همراه"}, {ORTH: "ش", NORM: "ش"}],
    "همسرتان": [{ORTH: "همسر", NORM: "همسر"}, {ORTH: "تان", NORM: "تان"}],
    "همسرش": [{ORTH: "همسر", NORM: "همسر"}, {ORTH: "ش", NORM: "ش"}],
    "همسرم": [{ORTH: "همسر", NORM: "همسر"}, {ORTH: "م", NORM: "م"}],
    "همفکرانش": [{ORTH: "همفکران", NORM: "همفکران"}, {ORTH: "ش", NORM: "ش"}],
    "همه‌اش": [{ORTH: "همه‌", NORM: "همه‌"}, {ORTH: "اش", NORM: "اش"}],
    "همه‌شان": [{ORTH: "همه‌", NORM: "همه‌"}, {ORTH: "شان", NORM: "شان"}],
    "همکارانش": [{ORTH: "همکاران", NORM: "همکاران"}, {ORTH: "ش", NORM: "ش"}],
    "هم‌نظریم": [{ORTH: "هم‌نظر", NORM: "هم‌نظر"}, {ORTH: "یم", NORM: "یم"}],
    "هنرش": [{ORTH: "هنر", NORM: "هنر"}, {ORTH: "ش", NORM: "ش"}],
    "هواست": [{ORTH: "هوا", NORM: "هوا"}, {ORTH: "ست", NORM: "ست"}],
    "هویتش": [{ORTH: "هویت", NORM: "هویت"}, {ORTH: "ش", NORM: "ش"}],
    "وابسته‌اند": [{ORTH: "وابسته‌", NORM: "وابسته‌"}, {ORTH: "اند", NORM: "اند"}],
    "واقفند": [{ORTH: "واقف", NORM: "واقف"}, {ORTH: "ند", NORM: "ند"}],
    "والدینشان": [{ORTH: "والدین", NORM: "والدین"}, {ORTH: "شان", NORM: "شان"}],
    "وجدان‌تان": [{ORTH: "وجدان‌", NORM: "وجدان‌"}, {ORTH: "تان", NORM: "تان"}],
    "وجودشان": [{ORTH: "وجود", NORM: "وجود"}, {ORTH: "شان", NORM: "شان"}],
    "وطنم": [{ORTH: "وطن", NORM: "وطن"}, {ORTH: "م", NORM: "م"}],
    "وعده‌اش": [{ORTH: "وعده‌", NORM: "وعده‌"}, {ORTH: "اش", NORM: "اش"}],
    "وقتمان": [{ORTH: "وقت", NORM: "وقت"}, {ORTH: "مان", NORM: "مان"}],
    "ولادتش": [{ORTH: "ولادت", NORM: "ولادت"}, {ORTH: "ش", NORM: "ش"}],
    "پایانش": [{ORTH: "پایان", NORM: "پایان"}, {ORTH: "ش", NORM: "ش"}],
    "پایش": [{ORTH: "پای", NORM: "پای"}, {ORTH: "ش", NORM: "ش"}],
    "پایین‌ترند": [{ORTH: "پایین‌تر", NORM: "پایین‌تر"}, {ORTH: "ند", NORM: "ند"}],
    "پدرت": [{ORTH: "پدر", NORM: "پدر"}, {ORTH: "ت", NORM: "ت"}],
    "پدرش": [{ORTH: "پدر", NORM: "پدر"}, {ORTH: "ش", NORM: "ش"}],
    "پدرشان": [{ORTH: "پدر", NORM: "پدر"}, {ORTH: "شان", NORM: "شان"}],
    "پدرم": [{ORTH: "پدر", NORM: "پدر"}, {ORTH: "م", NORM: "م"}],
    "پربارش": [{ORTH: "پربار", NORM: "پربار"}, {ORTH: "ش", NORM: "ش"}],
    "پروردگارت": [{ORTH: "پروردگار", NORM: "پروردگار"}, {ORTH: "ت", NORM: "ت"}],
    "پسرتان": [{ORTH: "پسر", NORM: "پسر"}, {ORTH: "تان", NORM: "تان"}],
    "پسرش": [{ORTH: "پسر", NORM: "پسر"}, {ORTH: "ش", NORM: "ش"}],
    "پسرعمویش": [{ORTH: "پسرعموی", NORM: "پسرعموی"}, {ORTH: "ش", NORM: "ش"}],
    "پسر‌عمویت": [{ORTH: "پسر‌عموی", NORM: "پسر‌عموی"}, {ORTH: "ت", NORM: "ت"}],
    "پشتش": [{ORTH: "پشت", NORM: "پشت"}, {ORTH: "ش", NORM: "ش"}],
    "پشیمونی": [{ORTH: "پشیمون", NORM: "پشیمون"}, {ORTH: "ی", NORM: "ی"}],
    "پولش": [{ORTH: "پول", NORM: "پول"}, {ORTH: "ش", NORM: "ش"}],
    "پژوهش‌هایش": [{ORTH: "پژوهش‌های", NORM: "پژوهش‌های"}, {ORTH: "ش", NORM: "ش"}],
    "پیامبرش": [{ORTH: "پیامبر", NORM: "پیامبر"}, {ORTH: "ش", NORM: "ش"}],
    "پیامبری": [{ORTH: "پیامبر", NORM: "پیامبر"}, {ORTH: "ی", NORM: "ی"}],
    "پیامش": [{ORTH: "پیام", NORM: "پیام"}, {ORTH: "ش", NORM: "ش"}],
    "پیداست": [{ORTH: "پیدا", NORM: "پیدا"}, {ORTH: "ست", NORM: "ست"}],
    "پیراهنش": [{ORTH: "پیراهن", NORM: "پیراهن"}, {ORTH: "ش", NORM: "ش"}],
    "پیروانش": [{ORTH: "پیروان", NORM: "پیروان"}, {ORTH: "ش", NORM: "ش"}],
    "پیشانی‌اش": [{ORTH: "پیشانی‌", NORM: "پیشانی‌"}, {ORTH: "اش", NORM: "اش"}],
    "پیمانت": [{ORTH: "پیمان", NORM: "پیمان"}, {ORTH: "ت", NORM: "ت"}],
    "پیوندشان": [{ORTH: "پیوند", NORM: "پیوند"}, {ORTH: "شان", NORM: "شان"}],
    "چاپش": [{ORTH: "چاپ", NORM: "چاپ"}, {ORTH: "ش", NORM: "ش"}],
    "چت": [{ORTH: "چ", NORM: "چ"}, {ORTH: "ت", NORM: "ت"}],
    "چته": [{ORTH: "چ", NORM: "چ"}, {ORTH: "ت", NORM: "ت"}, {ORTH: "ه", NORM: "ه"}],
    "چرخ‌هایش": [{ORTH: "چرخ‌های", NORM: "چرخ‌های"}, {ORTH: "ش", NORM: "ش"}],
    "چشمم": [{ORTH: "چشم", NORM: "چشم"}, {ORTH: "م", NORM: "م"}],
    "چشمهایش": [{ORTH: "چشمهای", NORM: "چشمهای"}, {ORTH: "ش", NORM: "ش"}],
    "چشمهایشان": [{ORTH: "چشمهای", NORM: "چشمهای"}, {ORTH: "شان", NORM: "شان"}],
    "چمنم": [{ORTH: "چمن", NORM: "چمن"}, {ORTH: "م", NORM: "م"}],
    "چهره‌اش": [{ORTH: "چهره‌", NORM: "چهره‌"}, {ORTH: "اش", NORM: "اش"}],
    "چکاره‌اند": [{ORTH: "چکاره‌", NORM: "چکاره‌"}, {ORTH: "اند", NORM: "اند"}],
    "چیزهاست": [{ORTH: "چیزها", NORM: "چیزها"}, {ORTH: "ست", NORM: "ست"}],
    "چیزهایش": [{ORTH: "چیزهای", NORM: "چیزهای"}, {ORTH: "ش", NORM: "ش"}],
    "چیزیست": [{ORTH: "چیزی", NORM: "چیزی"}, {ORTH: "ست", NORM: "ست"}],
    "چیست": [{ORTH: "چی", NORM: "چی"}, {ORTH: "ست", NORM: "ست"}],
    "کارش": [{ORTH: "کار", NORM: "کار"}, {ORTH: "ش", NORM: "ش"}],
    "کارشان": [{ORTH: "کار", NORM: "کار"}, {ORTH: "شان", NORM: "شان"}],
    "کارم": [{ORTH: "کار", NORM: "کار"}, {ORTH: "م", NORM: "م"}],
    "کارند": [{ORTH: "کار", NORM: "کار"}, {ORTH: "ند", NORM: "ند"}],
    "کارهایم": [{ORTH: "کارها", NORM: "کارها"}, {ORTH: "یم", NORM: "یم"}],
    "کافیست": [{ORTH: "کافی", NORM: "کافی"}, {ORTH: "ست", NORM: "ست"}],
    "کتابخانه‌اش": [{ORTH: "کتابخانه‌", NORM: "کتابخانه‌"}, {ORTH: "اش", NORM: "اش"}],
    "کتابش": [{ORTH: "کتاب", NORM: "کتاب"}, {ORTH: "ش", NORM: "ش"}],
    "کتابهاشان": [{ORTH: "کتابها", NORM: "کتابها"}, {ORTH: "شان", NORM: "شان"}],
    "کجاست": [{ORTH: "کجا", NORM: "کجا"}, {ORTH: "ست", NORM: "ست"}],
    "کدورتهایشان": [{ORTH: "کدورتهای", NORM: "کدورتهای"}, {ORTH: "شان", NORM: "شان"}],
    "کردنش": [{ORTH: "کردن", NORM: "کردن"}, {ORTH: "ش", NORM: "ش"}],
    "کرم‌خورده‌اش": [
        {ORTH: "کرم‌خورده‌", NORM: "کرم‌خورده‌"},
        {ORTH: "اش", NORM: "اش"},
    ],
    "کشش": [{ORTH: "کش", NORM: "کش"}, {ORTH: "ش", NORM: "ش"}],
    "کشورش": [{ORTH: "کشور", NORM: "کشور"}, {ORTH: "ش", NORM: "ش"}],
    "کشورشان": [{ORTH: "کشور", NORM: "کشور"}, {ORTH: "شان", NORM: "شان"}],
    "کشورمان": [{ORTH: "کشور", NORM: "کشور"}, {ORTH: "مان", NORM: "مان"}],
    "کشورهاست": [{ORTH: "کشورها", NORM: "کشورها"}, {ORTH: "ست", NORM: "ست"}],
    "کلیشه‌هاست": [{ORTH: "کلیشه‌ها", NORM: "کلیشه‌ها"}, {ORTH: "ست", NORM: "ست"}],
    "کمبودهاست": [{ORTH: "کمبودها", NORM: "کمبودها"}, {ORTH: "ست", NORM: "ست"}],
    "کمتره": [{ORTH: "کمتر", NORM: "کمتر"}, {ORTH: "ه", NORM: "ه"}],
    "کمکم": [{ORTH: "کمک", NORM: "کمک"}, {ORTH: "م", NORM: "م"}],
    "کنارش": [{ORTH: "کنار", NORM: "کنار"}, {ORTH: "ش", NORM: "ش"}],
    "کودکانشان": [{ORTH: "کودکان", NORM: "کودکان"}, {ORTH: "شان", NORM: "شان"}],
    "کوچکش": [{ORTH: "کوچک", NORM: "کوچک"}, {ORTH: "ش", NORM: "ش"}],
    "کیست": [{ORTH: "کی", NORM: "کی"}, {ORTH: "ست", NORM: "ست"}],
    "کیفش": [{ORTH: "کیف", NORM: "کیف"}, {ORTH: "ش", NORM: "ش"}],
    "گذشته‌اند": [{ORTH: "گذشته‌", NORM: "گذشته‌"}, {ORTH: "اند", NORM: "اند"}],
    "گرانقدرش": [{ORTH: "گرانقدر", NORM: "گرانقدر"}, {ORTH: "ش", NORM: "ش"}],
    "گرانقدرشان": [{ORTH: "گرانقدر", NORM: "گرانقدر"}, {ORTH: "شان", NORM: "شان"}],
    "گردنتان": [{ORTH: "گردن", NORM: "گردن"}, {ORTH: "تان", NORM: "تان"}],
    "گردنش": [{ORTH: "گردن", NORM: "گردن"}, {ORTH: "ش", NORM: "ش"}],
    "گرفتارند": [{ORTH: "گرفتار", NORM: "گرفتار"}, {ORTH: "ند", NORM: "ند"}],
    "گرفتنت": [{ORTH: "گرفتن", NORM: "گرفتن"}, {ORTH: "ت", NORM: "ت"}],
    "گروهند": [{ORTH: "گروه", NORM: "گروه"}, {ORTH: "ند", NORM: "ند"}],
    "گروگانهایش": [{ORTH: "گروگانهای", NORM: "گروگانهای"}, {ORTH: "ش", NORM: "ش"}],
    "گریمش": [{ORTH: "گریم", NORM: "گریم"}, {ORTH: "ش", NORM: "ش"}],
    "گفتارمان": [{ORTH: "گفتار", NORM: "گفتار"}, {ORTH: "مان", NORM: "مان"}],
    "گلهایش": [{ORTH: "گلهای", NORM: "گلهای"}, {ORTH: "ش", NORM: "ش"}],
    "گلویش": [{ORTH: "گلوی", NORM: "گلوی"}, {ORTH: "ش", NORM: "ش"}],
    "گناهت": [{ORTH: "گناه", NORM: "گناه"}, {ORTH: "ت", NORM: "ت"}],
    "گوشش": [{ORTH: "گوش", NORM: "گوش"}, {ORTH: "ش", NORM: "ش"}],
    "گوشم": [{ORTH: "گوش", NORM: "گوش"}, {ORTH: "م", NORM: "م"}],
    "گولش": [{ORTH: "گول", NORM: "گول"}, {ORTH: "ش", NORM: "ش"}],
    "یادتان": [{ORTH: "یاد", NORM: "یاد"}, {ORTH: "تان", NORM: "تان"}],
    "یادم": [{ORTH: "یاد", NORM: "یاد"}, {ORTH: "م", NORM: "م"}],
    "یادمان": [{ORTH: "یاد", NORM: "یاد"}, {ORTH: "مان", NORM: "مان"}],
    "یارانش": [{ORTH: "یاران", NORM: "یاران"}, {ORTH: "ش", NORM: "ش"}],
}



from ...symbols import NORM, ORTH

_exc = {}


for exc_data in [
    {ORTH: "ት/ቤት"},
    {ORTH: "ወ/ሮ", NORM: "ወይዘሮ"},
]:
    _exc[exc_data[ORTH]] = [exc_data]


for orth in [
    "ዓ.ም.",
    "ኪ.ሜ.",
]:
    _exc[orth] = [{ORTH: orth}]


TOKENIZER_EXCEPTIONS = _exc



import numpy
import pytest

from spacy.attrs import IS_ALPHA, IS_DIGIT, IS_LOWER, IS_PUNCT, IS_STOP, IS_TITLE
from spacy.symbols import VERB
from spacy.tokens import Doc
from spacy.training import Example
from spacy.vocab import Vocab


@pytest.fixture
def doc(en_vocab):
    # fmt: off
    words = ["This", "is", "a", "sentence", ".", "This", "is", "another", "sentence", ".", "And", "a", "third", "."]
    heads = [1, 1, 3, 1, 1, 6, 6, 8, 6, 6, 10, 12, 10, 12]
    deps = ["nsubj", "ROOT", "det", "attr", "punct", "nsubj", "ROOT", "det",
            "attr", "punct", "ROOT", "det", "npadvmod", "punct"]
    # fmt: on
    return Doc(en_vocab, words=words, heads=heads, deps=deps)


def test_doc_token_api_strings(en_vocab):
    words = ["Give", "it", "back", "!", "He", "pleaded", "."]
    pos = ["VERB", "PRON", "PART", "PUNCT", "PRON", "VERB", "PUNCT"]
    heads = [0, 0, 0, 0, 5, 5, 5]
    deps = ["ROOT", "dobj", "prt", "punct", "nsubj", "ROOT", "punct"]
    doc = Doc(en_vocab, words=words, pos=pos, heads=heads, deps=deps)
    assert doc[0].orth_ == "Give"
    assert doc[0].text == "Give"
    assert doc[0].text_with_ws == "Give "
    assert doc[0].lower_ == "give"
    assert doc[0].shape_ == "Xxxx"
    assert doc[0].prefix_ == "G"
    assert doc[0].suffix_ == "ive"
    assert doc[0].pos_ == "VERB"
    assert doc[0].dep_ == "ROOT"


def test_doc_token_api_flags(en_tokenizer):
    text = "Give it back! He pleaded."
    tokens = en_tokenizer(text)
    assert tokens[0].check_flag(IS_ALPHA)
    assert not tokens[0].check_flag(IS_DIGIT)
    assert tokens[0].check_flag(IS_TITLE)
    assert tokens[1].check_flag(IS_LOWER)
    assert tokens[3].check_flag(IS_PUNCT)
    assert tokens[2].check_flag(IS_STOP)
    assert not tokens[5].check_flag(IS_STOP)
    # TODO: Test more of these, esp. if a bug is found


@pytest.mark.parametrize("text", ["Give it back! He pleaded."])
def test_doc_token_api_prob_inherited_from_vocab(en_tokenizer, text):
    word = text.split()[0]
    en_tokenizer.vocab[word].prob = -1
    tokens = en_tokenizer(text)
    assert tokens[0].prob != 0


@pytest.mark.parametrize("text", ["one two"])
def test_doc_token_api_str_builtin(en_tokenizer, text):
    tokens = en_tokenizer(text)
    assert str(tokens[0]) == text.split(" ")[0]
    assert str(tokens[1]) == text.split(" ")[1]


def test_doc_token_api_is_properties(en_vocab):
    doc = Doc(en_vocab, words=["Hi", ",", "my", "email", "is", "test@me.com"])
    assert doc[0].is_title
    assert doc[0].is_alpha
    assert not doc[0].is_digit
    assert doc[1].is_punct
    assert doc[3].is_ascii
    assert not doc[3].like_url
    assert doc[4].is_lower
    assert doc[5].like_email


def test_doc_token_api_vectors():
    vocab = Vocab()
    vocab.reset_vectors(width=2)
    vocab.set_vector("apples", vector=numpy.asarray([0.0, 2.0], dtype="f"))
    vocab.set_vector("oranges", vector=numpy.asarray([0.0, 1.0], dtype="f"))
    doc = Doc(vocab, words=["apples", "oranges", "oov"])
    assert doc.has_vector
    assert doc[0].has_vector
    assert doc[1].has_vector
    assert not doc[2].has_vector
    apples_norm = (0 * 0 + 2 * 2) ** 0.5
    oranges_norm = (0 * 0 + 1 * 1) ** 0.5
    cosine = ((0 * 0) + (2 * 1)) / (apples_norm * oranges_norm)
    assert doc[0].similarity(doc[1]) == cosine


def test_doc_token_api_ancestors(en_vocab):
    # the structure of this sentence depends on the English annotation scheme
    words = ["Yesterday", "I", "saw", "a", "dog", "that", "barked", "loudly", "."]
    heads = [2, 2, 2, 4, 2, 6, 4, 6, 2]
    deps = ["dep"] * len(heads)
    doc = Doc(en_vocab, words=words, heads=heads, deps=deps)
    assert [t.text for t in doc[6].ancestors] == ["dog", "saw"]
    assert [t.text for t in doc[1].ancestors] == ["saw"]
    assert [t.text for t in doc[2].ancestors] == []
    assert doc[2].is_ancestor(doc[7])
    assert not doc[6].is_ancestor(doc[2])


def test_doc_token_api_head_setter(en_vocab):
    words = ["Yesterday", "I", "saw", "a", "dog", "that", "barked", "loudly", "."]
    heads = [2, 2, 2, 4, 2, 6, 4, 6, 2]
    deps = ["dep"] * len(heads)
    doc = Doc(en_vocab, words=words, heads=heads, deps=deps)
    assert doc[6].n_lefts == 1
    assert doc[6].n_rights == 1
    assert doc[6].left_edge.i == 5
    assert doc[6].right_edge.i == 7
    assert doc[4].n_lefts == 1
    assert doc[4].n_rights == 1
    assert doc[4].left_edge.i == 3
    assert doc[4].right_edge.i == 7
    assert doc[3].n_lefts == 0
    assert doc[3].n_rights == 0
    assert doc[3].left_edge.i == 3
    assert doc[3].right_edge.i == 3
    assert doc[2].left_edge.i == 0
    assert doc[2].right_edge.i == 8

    doc[6].head = doc[3]
    assert doc[6].n_lefts == 1
    assert doc[6].n_rights == 1
    assert doc[6].left_edge.i == 5
    assert doc[6].right_edge.i == 7
    assert doc[3].n_lefts == 0
    assert doc[3].n_rights == 1
    assert doc[3].left_edge.i == 3
    assert doc[3].right_edge.i == 7
    assert doc[4].n_lefts == 1
    assert doc[4].n_rights == 0
    assert doc[4].left_edge.i == 3
    assert doc[4].right_edge.i == 7
    assert doc[2].left_edge.i == 0
    assert doc[2].right_edge.i == 8

    doc[0].head = doc[5]
    assert doc[5].left_edge.i == 0
    assert doc[6].left_edge.i == 0
    assert doc[3].left_edge.i == 0
    assert doc[4].left_edge.i == 0
    assert doc[2].left_edge.i == 0
    # head token must be from the same document
    doc2 = Doc(en_vocab, words=words, heads=heads, deps=["dep"] * len(heads))
    with pytest.raises(ValueError):
        doc[0].head = doc2[0]
    # test sentence starts when two sentences are joined
    # fmt: off
    words = ["This", "is", "one", "sentence", ".", "This", "is", "another", "sentence", "."]
    heads = [0, 0, 0, 0, 0, 5, 5, 5, 5, 5]
    # fmt: on
    doc = Doc(en_vocab, words=words, heads=heads, deps=["dep"] * len(heads))
    # initially two sentences
    assert doc[0].is_sent_start
    assert doc[5].is_sent_start
    assert doc[0].left_edge == doc[0]
    assert doc[0].right_edge == doc[4]
    assert doc[5].left_edge == doc[5]
    assert doc[5].right_edge == doc[9]
    # modifying with a sentence doesn't change sent starts
    doc[2].head = doc[3]
    assert doc[0].is_sent_start
    assert doc[5].is_sent_start
    assert doc[0].left_edge == doc[0]
    assert doc[0].right_edge == doc[4]
    assert doc[5].left_edge == doc[5]
    assert doc[5].right_edge == doc[9]
    # attach the second sentence to the first, resulting in one sentence
    doc[5].head = doc[0]
    assert doc[0].is_sent_start
    assert not doc[5].is_sent_start
    assert doc[0].left_edge == doc[0]
    assert doc[0].right_edge == doc[9]


def test_is_sent_start(en_tokenizer):
    doc = en_tokenizer("This is a sentence. This is another.")
    assert doc[5].is_sent_start is None
    doc[5].is_sent_start = True
    assert doc[5].is_sent_start is True
    assert len(list(doc.sents)) == 2


def test_is_sent_end(en_tokenizer):
    doc = en_tokenizer("This is a sentence. This is another.")
    assert doc[4].is_sent_end is None
    doc[5].is_sent_start = True
    assert doc[4].is_sent_end is True
    assert len(list(doc.sents)) == 2


def test_set_pos():
    doc = Doc(Vocab(), words=["hello", "world"])
    doc[0].pos_ = "NOUN"
    assert doc[0].pos_ == "NOUN"
    doc[1].pos = VERB
    assert doc[1].pos_ == "VERB"


def test_set_invalid_pos():
    doc = Doc(Vocab(), words=["hello", "world"])
    with pytest.raises(ValueError):
        doc[0].pos_ = "blah"


def test_tokens_sent(doc):
    """Test token.sent property"""
    assert len(list(doc.sents)) == 3
    assert doc[1].sent.text == "This is a sentence ."
    assert doc[7].sent.text == "This is another sentence ."
    assert doc[1].sent.root.left_edge.text == "This"
    assert doc[7].sent.root.left_edge.text == "This"


def test_token0_has_sent_start_true():
    doc = Doc(Vocab(), words=["hello", "world"])
    assert doc[0].is_sent_start is True
    assert doc[1].is_sent_start is None
    assert not doc.has_annotation("SENT_START")


def test_tokenlast_has_sent_end_true():
    doc = Doc(Vocab(), words=["hello", "world"])
    assert doc[0].is_sent_end is None
    assert doc[1].is_sent_end is True
    assert not doc.has_annotation("SENT_START")


def test_token_api_conjuncts_chain(en_vocab):
    words = ["The", "boy", "and", "the", "girl", "and", "the", "man", "went", "."]
    heads = [1, 8, 1, 4, 1, 4, 7, 4, 8, 8]
    deps = ["det", "nsubj", "cc", "det", "conj", "cc", "det", "conj", "ROOT", "punct"]
    doc = Doc(en_vocab, words=words, heads=heads, deps=deps)
    assert [w.text for w in doc[1].conjuncts] == ["girl", "man"]
    assert [w.text for w in doc[4].conjuncts] == ["boy", "man"]
    assert [w.text for w in doc[7].conjuncts] == ["boy", "girl"]


def test_token_api_conjuncts_simple(en_vocab):
    words = ["They", "came", "and", "went", "."]
    heads = [1, 1, 1, 1, 3]
    deps = ["nsubj", "ROOT", "cc", "conj", "dep"]
    doc = Doc(en_vocab, words=words, heads=heads, deps=deps)
    assert [w.text for w in doc[1].conjuncts] == ["went"]
    assert [w.text for w in doc[3].conjuncts] == ["came"]


def test_token_api_non_conjuncts(en_vocab):
    words = ["They", "came", "."]
    heads = [1, 1, 1]
    deps = ["nsubj", "ROOT", "punct"]
    doc = Doc(en_vocab, words=words, heads=heads, deps=deps)
    assert [w.text for w in doc[0].conjuncts] == []
    assert [w.text for w in doc[1].conjuncts] == []


def test_missing_head_dep(en_vocab):
    """Check that the Doc constructor and Example.from_dict parse missing information the same"""
    heads = [1, 1, 1, 1, 2, None]  # element 5 is missing
    deps = ["", "ROOT", "dobj", "cc", "conj", None]  # element 0 and 5 are missing
    words = ["I", "like", "London", "and", "Berlin", "."]
    doc = Doc(en_vocab, words=words, heads=heads, deps=deps)
    pred_has_heads = [t.has_head() for t in doc]
    pred_has_deps = [t.has_dep() for t in doc]
    pred_heads = [t.head.i for t in doc]
    pred_deps = [t.dep_ for t in doc]
    pred_sent_starts = [t.is_sent_start for t in doc]
    assert pred_has_heads == [False, True, True, True, True, False]
    assert pred_has_deps == [False, True, True, True, True, False]
    assert pred_heads[1:5] == [1, 1, 1, 2]
    assert pred_deps[1:5] == ["ROOT", "dobj", "cc", "conj"]
    assert pred_sent_starts == [True, False, False, False, False, False]
    example = Example.from_dict(doc, {"heads": heads, "deps": deps})
    ref_has_heads = [t.has_head() for t in example.reference]
    ref_has_deps = [t.has_dep() for t in example.reference]
    ref_heads = [t.head.i for t in example.reference]
    ref_deps = [t.dep_ for t in example.reference]
    ref_sent_starts = [t.is_sent_start for t in example.reference]
    assert ref_has_heads == pred_has_heads
    assert ref_has_deps == pred_has_heads
    assert ref_heads == pred_heads
    assert ref_deps == pred_deps
    assert ref_sent_starts == pred_sent_starts
    # check that the aligned parse preserves the missing information
    aligned_heads, aligned_deps = example.get_aligned_parse(projectivize=True)
    assert aligned_deps[0] == ref_deps[0]
    assert aligned_heads[0] == ref_heads[0]
    assert aligned_deps[5] == ref_deps[5]
    assert aligned_heads[5] == ref_heads[5]


def test_token_api_richcmp_other(en_tokenizer):
    doc1 = en_tokenizer("a b")
    doc2 = en_tokenizer("b c")
    assert not doc1[1] == doc1[0:1]
    assert not doc1[1] == doc2[1:2]
    assert not doc1[1] == doc2[0]
    assert not doc1[0] == doc2



# from https://prpm.dbp.gov.my/cari1?keyword=
# dbp https://en.wikipedia.org/wiki/Dewan_Bahasa_dan_Pustaka
MS_BASE_EXCEPTIONS = set(
    """
aba-aba
abah-abah
abar-abar
abrit-abritan
abu-abu
abuk-abuk
abun-abun
acak-acak
acak-acakan
acang-acang
aci-aci
aci-acian
aci-acinya
adang-adang
adap-adapan
adik-beradik
aduk-adukan
agak-agak
agar-agar
agut-agut
air-cooled
ajar-ajar
aji-aji
akal-akal
akhir-akhir
aki-aki
alah-mengalahi
alan-alan
alang-alang
alang-alangan
alap-alap
ali-ali
alih-alih
aling-aling
aling-alingan
alip-alipan
alon-alon
alu-alu
alu-aluan
alun-alun
alur-alur
ambah-ambah
ambai-ambai
ambil-mengambil
ambring-ambringan
ambu-ambu
ambung-ambung
amin-amin
ampai-ampai
amung-amung
anai-anai
anak-anak
anak-anakan
anak-beranak
ancak-ancak
ancang-ancang
andang-andang
angan-angan
anggar-anggar
angin-angin
angin-anginan
angkul-angkul
angkup-angkup
angkut-angkut
ani-ani
aning-aning
anjang-anjang
anjing-anjing
anjung-anjung
anjung-anjungan
antar-antar
ante-mortem
anting-anting
antung-antung
anyam-menganyam
apa-apa
api-api
apit-apit
aprit-apritan
arah-arah
arak-arakan
aram-aram
ari-ari
aru-aru
asa-asaan
asam-asaman
asuh-asuh
atas-mengatasi
ati-ati
audio-visual
avant-garde
awang-awang
awang-gemawang
ayak-ayak
ayam-ayam
ayam-ayaman
ayang-ayang
ayeng-ayengan
ayun-temayun
back-up
bahu-membahu
baik-baik
bajang-bajang
baji-baji
balai-balai
balam-balam
balas-membalas
baling-baling
balut-balut
bangun-bangun
bantal-bantal
barat-barat
barau-barau
bari-bari
barung-barung
basa-basi
bata-bata
batir-batir
bau-bauan
bayang-bayang
bedil-bedal
begana-begini
bekal-bekalan
belat-belit
belu-belai
benggal-benggil
bengkal-bengkil
bengkang-bengkok
bengkang-bengkong
berabad-abad
berabun-rabun
berada-ada
beragah-agah
beragak-agak
beragam-ragam
beraja-raja
berakit-rakit
beraku-akuan
beralun-alun
beramah-ramahan
beramah-tamah
beramai-ramai
berambai-ambai
berambal-ambalan
beramuk-amukan
berandai-andai
berandai-randai
berang-berang
berangan-angan
beranggap-anggapan
berangguk-angguk
berangin-angin
berangka-angka
berangka-angkaan
berangkai-rangkai
beranja-anja
berantai-rantai
berapi-api
berapung-apung
berarak-arakan
beras-beras
berasing-asingan
beratus-ratus
berawas-awas
berayal-ayalan
berayun-ayun
berbagai-bagai
berbahas-bahasan
berbalas-balasan
berbalik-balik
berbanjar-banjar
berbantah-bantah
berbanyak-banyak
berbarik-barik
berbasah-basah
berbatu-batu
berbayang-bayang
berbecak-becak
berbedil-bedilan
berbeka-beka
berbelakang-belakangan
berbelang-belang
berbeli-belian
berbelit-belit
berbelok-belok
berbenar-benar
berbencah-bencah
berbesar-besar
berbidai-bidai
berbiku-biku
berbilik-bilik
berbinar-binar
berbincang-bincang
berbingkah-bingkah
berbintang-bintang
berbintik-bintik
berbintil-bintil
berbisik-bisik
berbolak-balik
berbolong-bolong
berbondong-bondong
berbongkah-bongkah
berbuai-buai
berbual-bual
berbukit-bukit
berbulan-bulan
berbunga-bunga
berbuntut-buntut
berbunuh-bunuhan
berburu-buru
berburuk-buruk
berbutir-butir
bercabang-cabang
bercaci-cacian
bercakap-cakap
bercakar-cakaran
bercantik-cantik
bercari-cari
bercari-carian
bercarik-carik
bercepat-cepat
bercerai-berai
bercerai-cerai
bercetai-cetai
bercikun-cikun
bercinta-cintaan
bercita-cita
berciut-ciut
berconteng-conteng
bercoreng-coreng
bercoreng-moreng
bercuit-cuit
bercumbu-cumbu
bercumbu-cumbuan
bercura-bura
bercura-cura
berdada-dadaan
berdahulu-dahuluan
berdalam-dalam
berdebar-debar
berdecap-decap
berdedai-dedai
berdegap-degap
berdegar-degar
berdeham-deham
berdekah-dekah
berdekat-dekat
berdelat-delat
berdembun-dembun
berdempang-dempang
berdendam-dendaman
berdengkang-dengkang
berdentang-dentang
berdentum-dentum
berdentung-dentung
berdepak-depak
berdepan-depan
berderai-derai
berderak-derak
berderau-derau
berdering-dering
berderung-derung
berdesak-desakan
berdesing-desing
berdesus-desus
berdikit-dikit
berdingkit-dingkit
berdua-dua
berduri-duri
berduru-duru
berduyun-duyun
berebut-rebut
berebut-rebutan
beregang-regang
berek-berek
berembut-rembut
berempat-empat
berenak-enak
berenteng-renteng
beresah-resah
berfoya-foya
bergagah-gagahan
bergagap-gagap
bergalur-galur
berganda-ganda
berganti-ganti
bergarah-garah
bergaruk-garuk
bergegas-gegas
bergelang-gelang
bergelap-gelap
bergelas-gelasan
bergeleng-geleng
bergemal-gemal
bergembut-gembut
bergerek-gerek
bergesa-gesa
bergilir-gilir
bergolek-golek
bergores-gores
bergotong-royong
bergugus-gugus
bergulung-gulung
bergulut-gulut
bergumpal-gumpal
bergunung-gunung
berhadap-hadapan
berhamun-hamun
berhandai-handai
berhanyut-hanyut
berhari-hari
berhati-hati
berhilau-hilau
berhujan-hujan
beria-ia
beria-ria
beriak-riak
beribu-ribu
berigi-rigi
bering-bering
beringat-ingat
beringgit-ringgit
berintik-rintik
beriring-iring
beriring-iringan
berjabir-jabir
berjaga-jaga
berjagung-jagung
berjalan-jalan
berjalar-jalar
berjalin-jalin
berjalur-jalur
berjam-jam
berjauh-jauhan
berjejal-jejal
berjela-jela
berjenis-jenis
berjenjang-jenjang
berjilid-jilid
berjinak-jinak
berjingkat-jingkat
berjingkrak-jingkrak
berjongkok-jongkok
berjubel-jubel
berjujut-jujutan
berjulai-julai
berjumbai-jumbai
berjurai-jurai
berjurus-jurus
berjuta-juta
berkaca-kaca
berkait-kaitan
berkala-kala
berkali-kali
berkanjar-kanjar
berkaok-kaok
berkarung-karung
berkasih-kasihan
berkata-kata
berkatak-katak
berkecai-kecai
berkecek-kecek
berkecil-kecil
berkecil-kecilan
berkedip-kedip
berkejang-kejang
berkejap-kejap
berkejar-kejaran
berkelar-kelar
berkelip-kelip
berkelit-kelit
berkelok-kelok
berkelompok-kelompok
berkelun-kelun
berkembur-kembur
berkempul-kempul
berkena-kenaan
berkenal-kenalan
berkendur-kendur
berkeok-keok
berkepak-kepak
berkepal-kepal
berkeping-keping
berkepul-kepul
berkeras-kerasan
berkeritik-keritik
berkeruit-keruit
berkerut-kerut
berketak-ketak
berketak-ketik
berketi-keti
berketil-ketil
berketuk-ketak
berketul-ketul
berkial-kial
berkian-kian
berkias-kiasan
berkibar-kibar
berkilah-kilah
berkilat-kilat
berkilau-kilauan
berkilo-kilo
berkinja-kinja
berkipas-kipas
berkira-kira
berkirim-kiriman
berkobar-kobar
berkobok-kobok
berkocak-kocak
berkodi-kodi
berkolek-kolek
berkopah-kopah
berkotak-kotak
berkuat-kuatan
berkunang-kunang
berkurun-kurun
berkusau-kusau
berkusu-kusu
berkusut-kusut
berkuting-kuting
berkutu-kutuan
berlabun-labun
berlain-lainan
berlalai-lalai
berlama-lama
berlambai-lambai
berlambak-lambak
berlampang-lampang
berlapang-lapang
berlapis-lapis
berlapuk-lapuk
berlarah-larah
berlarat-larat
berlari-larian
berlarik-larik
berlarut-larut
berlawak-lawak
berlayap-layapan
berlebih-lebih
berlebih-lebihan
berlekas-lekas
berlena-lena
berlengah-lengah
berlenggek-lenggek
berlenggok-lenggok
berleret-leret
berliang-liuk
berliku-liku
berlimpah-limpah
berlimpap-limpap
berlimpit-limpit
berlinang-linang
berlindak-lindak
berlipat-lipat
berlompok-lompok
berloncat-loncatan
berlopak-lopak
berlubang-lubang
bermaaf-maafan
bermacam-macam
bermain-main
bermalas-malas
bermanik-manik
bermanis-manis
bermanja-manja
bermasak-masak
bermati-mati
bermegah-megah
bermemek-memek
bermesra-mesraan
bermewah-mewah
berminggu-minggu
berminta-minta
bermuda-muda
bermudah-mudah
bermuka-muka
bermula-mula
bermulut-mulut
bernafsi-nafsi
bernaka-naka
berniat-niat
berogak-ogak
beroleng-oleng
berolok-olok
beromong-omong
beronggok-onggok
berorang-orang
beroyal-royal
berpada-pada
berpahit-pahit
berpair-pair
berpal-pal
berpalu-palu
berpalu-paluan
berpalun-palun
berpandai-pandai
berpandang-pandangan
berpangkat-pangkat
berpanjang-panjang
berpasang-pasang
berpasang-pasangan
berpayah-payah
berpeluh-peluh
berpeluk-pelukan
berpenat-penat
berpencar-pencar
berpendar-pendar
berpenggal-penggal
berperai-perai
berpesai-pesai
berpesta-pesta
berpesuk-pesuk
berpetak-petak
berpeti-peti
berpihak-pihak
berpijar-pijar
berpikul-pikul
berpilih-pilih
berpilin-pilin
berpindah-pindah
berpintal-pintal
berpirau-pirau
berpisah-pisah
berpolah-polah
berpongah-pongah
berpontang-panting
berporah-porah
berpotong-potong
berpuak-puak
berpual-pual
berpugak-pugak
berpuluh-puluh
berpulun-pulun
berpuntal-puntal
berpura-pura
berpusar-pusar
berpusing-pusing
berpusu-pusu
berputar-putar
bersaf-saf
bersahut-sahutan
bersakit-sakit
bersalah-salahan
bersalam-salaman
bersalin-salin
bersama-sama
bersambut-sambutan
bersampan-sampan
bersantai-santai
bersapa-sapaan
bersarang-sarang
bersedan-sedan
bersedia-sedia
bersedu-sedu
bersekat-sekat
berselang-selang
berselang-seli
bersembur-semburan
bersempit-sempit
bersenang-senang
bersenang-senangkan
bersenda-senda
bersendi-sendi
bersepah-sepah
bersepi-sepi
berserak-serak
berseri-seri
bersesak-sesak
bersetai-setai
bersia-sia
bersiap-siap
bersiar-siar
bersilir-silir
bersimbur-simburan
bersinau-sinau
bersorak-sorai
bersuap-suapan
bersudah-sudah
bersuka-suka
bersuka-sukaan
bersuku-suku
bersumpah-sumpahan
bersungguh-sungguh
bersungut-sungut
bersunyi-sunyi
bersusah-susah
bersusuk-susuk
bersusuk-susukan
bersutan-sutan
bertabur-tabur
bertahu-tahu
bertahun-tahun
bertajuk-tajuk
bertakik-takik
bertala-tala
bertali-tali
bertalu-talu
bertambah-tambah
bertanda-tandaan
bertangis-tangisan
bertangkil-tangkil
bertanya-tanya
bertarik-tarikan
bertatai-tatai
bertatih-tatih
bertawan-tawan
bertawar-tawaran
bertebu-tebu
bertebu-tebukan
berteguh-teguh
berteguh-teguhan
berteka-teki
bertelau-telau
bertele-tele
bertempat-tempat
bertempuh-tempuh
bertenang-tenang
bertenggang-tenggangan
bertentu-tentu
bertepek-tepek
berterang-terang
berterang-terangan
bertikam-tikaman
bertimbal-timbalan
bertimbun-timbun
bertimpa-timpa
bertimpas-timpas
bertingkah-tingkah
bertingkat-tingkat
bertinjau-tinjauan
bertiras-tiras
bertitar-titar
bertoboh-toboh
bertolak-tolak
bertolak-tolakan
bertolong-tolongan
bertonjol-tonjol
bertua-tua
bertua-tuaan
bertual-tual
bertubi-tubi
bertukar-tukar
bertukar-tukaran
bertukas-tukas
bertumpak-tumpak
bertunda-tunda
bertunjuk-tunjukan
bertura-tura
berturut-turut
bertutur-tutur
beruas-ruas
berubah-ubah
berulang-alik
berulang-ulang
berumbai-rumbai
berundung-undung
berunggas-runggas
berungkur-ungkuran
beruntai-untai
beruntun-runtun
berunyai-unyai
berupa-rupa
berura-ura
beruris-uris
berurut-urutan
berwarna-warna
berwarna-warni
berwindu-windu
berwiru-wiru
beryang-yang
besar-besaran
betak-betak
beti-beti
betul-betul
biang-biang
biar-biar
biji-bijian
bila-bila
bilang-bilang
bincang-bincut
bini-binian
biri-biri
biru-biru
bisik-bisik
biti-biti
bolak-balik
bolang-baling
bongkar-bangkir
buah-buahan
buat-buatan
buaya-buaya
bubun-bubun
bugi-bugi
built-in
bukan-bukan
bulan-bulan
bulan-bulanan
bulang-bulang
bulat-bulat
buli-buli
bulu-bulu
buluh-buluh
bulus-bulus
bunga-bungaan
bunuh-membunuh
bunyi-bunyian
buru-buru
burung-burungan
bye-bye
cabik-cabik
caing-caing
calar-balar
cara-cara
carut-marut
cawi-cawi
cebar-cebur
celam-celum
celangak-celinguk
celas-celus
celedang-celedok
celengkak-celengkok
cemas-cemas
centang-perenang
cepat-cepat
cerai-berai
ceruk-menceruk
ceruk-meruk
check-up
chit-chat
cirit-birit
cita-cita
close-up
closed-circuit
cobak-cabik
cobar-cabir
cola-cala
compang-camping
congak-cangit
congkah-cangkih
congkah-mangkih
copak-capik
corak-carik
corat-coret
coreng-moreng
cuang-caing
cubung-cubung
culik-culik
cuma-cuma
cumi-cumi
cungap-cangip
cupu-cupu
dahulu-mendahului
dali-dali
dapur-dapur
dari-dari
daru-daru
datang-datang
datang-mendatangi
daun-daunan
dawai-dawai
dayang-dayang
degap-degap
dekak-dekak
dekat-dekat
dengar-dengaran
desas-desus
diam-diam
do-it-yourself
dokok-dokok
dolak-dalik
dorong-mendorong
drive-in
dua-dua
dua-duanya
duduk-duduk
dulang-dulang
ecek-ecek
embuh-embuhan
empek-empek
empok-empok
encal-encal
endap-endap
endut-endutan
engah-engah
enggan-enggan
engkah-engkah
entah-berentah
erang-erot
erong-erong
fast-food
fifty-fifty
flip-flop
follow-up
foya-foya
gaba-gaba
gabai-gabai
gada-gada
gading-gading
gado-gado
gajah-gajahan
gala-gala
gali-galian
galing-galing
galu-galu
gamit-gamitan
gampang-gampangan
ganal-ganal
ganda-berganda
gapah-gopoh
gara-gara
garah-garah
gatal-gatal
gawar-gawar
gaya-gayanya
gedebak-gedebuk
gelang-gelang
gelembung-gelembungan
geli-geli
geliang-geliut
geliat-geliut
gempul-gempul
gendang-gendang
genjang-genjot
gerabak-gerubuk
gerak-gerik
gerbas-gerbus
gerit-gerit
geruh-gerah
getak-getuk
geti-geti
gila-gila
gila-gilaan
gilang-gemilang
gilap-gemilap
gili-gili
giling-giling
ginang-ginang
girik-girik
giring-giring
go-kart
golak-galik
gonta-ganti
gotong-royong
gual-gail
gudu-gudu
gula-gula
gulang-gulang
guna-guna
guntang-guntang
gunung-ganang
gunung-gemunung
gunung-gunungan
habis-habis
habis-habisan
halai-balai
half-time
hampir-hampir
harap-harapan
harum-haruman
hati-hati
heavy-duty
hebat-hebatan
hidup-hidup
hiru-biru
hiruk-pikuk
hubaya-hubaya
hula-hula
huru-hara
ibar-ibar
icak-icak
igau-igauan
ikut-ikut
ikut-ikutan
ilam-ilam
imbang-imbangan
inang-inang
inca-binca
incang-incut
ingat-ingat
ingat-ingatan
ingau-ingauan
inggang-inggung
injak-injak
iras-iras
iring-iringan
iseng-iseng
jadi-jadian
jala-jala
jamah-jamahan
jambu-jambu
jangan-jangan
jarang-jarang
jari-jari
jaring-jaring
jarum-jarum
jauh-jauh
jawi-jawi
jebat-jebatan
jelur-jelir
jendal-jendul
jenggar-jenggur
jentik-jentik
jerah-jerih
jolong-jolong
jongkar-jangkir
juak-juak
juang-juang
julung-julung
jurai-jurai
kabu-kabu
kacang-kacang
kacang-kacangan
kacau-balau
kadang-kadang
kail-kail
kait-kait
kakek-kakek
kalau-kalau
kaleng-kalengan
kalut-malut
kambing-kambing
kanak-kanak
kapa-kapa
kapan-kapan
kapu-kapu
karang-karangan
karang-mengarang
kareseh-peseh
karut-marut
katang-katang
kawa-kawa
kayu-kayuan
keabu-abuan
keasyik-asyikan
kebarat-baratan
kebasah-basahan
kebat-kebit
kebata-bataan
kebelanda-belandaan
kebiru-biruan
kebudak-budakan
kecil-kecilan
kecil-mengecil
kecuh-kecah
kedek-kedek
kegadis-gadisan
kegelap-gelapan
kegila-gilaan
kegirang-girangan
kehijau-hijauan
kehitam-hitaman
kejaga-jagaan
kejingga-jinggaan
kekabur-kaburan
kekanak-kanakan
kekoboi-koboian
kekuning-kuningan
kelak-kelik
kelak-keluk
kelaki-lakian
kelang-kelok
kelap-kelip
kelek-kelek
kelek-kelekan
kelik-kelik
kelip-kelip
kelusuh-kelasah
kelut-melut
kemak-kemik
kemalu-maluan
kemanja-manjaan
kemarah-marahan
kemasam-masaman
kemati-matian
kemerah-merahan
kempang-kempis
kempas-kempis
kemuda-mudaan
kena-mengena
kenal-mengenal
kenang-kenangan
kencang-kencung
kendang-kendang
kendang-kendangan
kentung-kentung
kenyat-kenyit
kepandir-pandiran
kepang-kepot
keperak-perakan
kepilu-piluan
kepura-puraan
keputih-putihan
kerah-kerahan
kerancak-rancakan
kerang-kerangan
kerang-keroh
kerang-kerung
kerap-kerap
keras-mengerasi
kercap-kercip
kercap-kercup
keriang-keriut
kernyat-kernyut
kerong-kerong
keropas-kerapis
kertak-kertuk
keruntang-pungkang
kesap-kesip
kesenak-senakan
kesewenang-wenangan
kesia-siaan
kesik-kesik
kesipu-sipuan
kesu-kesi
kesuh-kesih
kesuk-kesik
ketergesa-gesaan
keti-keti
ketidur-tiduran
ketiga-tiganya
ketua-tuaan
ketuan-tuanan
keungu-unguan
kia-kia
kiak-kiak
kial-kial
kiang-kiut
kibang-kibut
kicang-kecoh
kicang-kicu
kida-kida
kilau-mengilau
kili-kili
kira-kira
kira-kiraan
kisi-kisi
kocah-kacih
kodok-kodok
kolang-kaling
koleh-koleh
kolong-kolong
koma-koma
komat-kamit
kontal-kantil
kontang-kanting
kosak-kasik
kotak-katik
kotak-kotak
kuat-kuat
kucar-kacir
kucing-kucing
kucing-kucingan
kuda-kuda
kuda-kudaan
kudap-kudap
kulah-kulah
kulak-kulak
kulik-kulik
kulum-kulum
kumat-kamit
kunang-kunang
kupat-kapit
kupu-kupu
kura-kura
kurang-kurang
kusat-mesat
kutat-kutet
kuti-kuti
labi-labi
labu-labu
lagi-lagi
laguh-lagah
laki-laki
lalu-lalang
lama-kelamaan
lama-lama
lamat-lamat
lambat-lambat
lancar-lancar
langak-longok
langit-langit
lanja-lanjaan
lapat-lapat
large-scale
lari-lari
lauk-pauk
lawah-lawah
lawak-lawak
lawi-lawi
layang-layang
layu-layuan
lebih-lebih
legak-legok
lekak-lekuk
lekap-lekup
lekas-lekas
lekuh-lekih
lekup-lekap
lenggak-lenggok
lenggok-lenggok
lengket-lengket
lentam-lentum
lentang-lentok
lentang-lentung
lepa-lepa
lerang-lerang
lereng-lereng
letah-letai
letup-letup
liang-liuk
lidah-lidah
line-up
liuk-liuk
liung-liung
lobi-lobi
lock-up
lopak-lapik
lopak-lopak
lumba-lumba
lumi-lumi
luntang-lantung
lupa-lupa
lupa-lupaan
main-mainan
makan-makanan
make-up
malai-malai
malam-malam
malar-malar
mali-mali
malu-malu
mana-mana
manik-manik
manis-manisan
mark-up
masing-masing
mata-mata
mati-matian
maya-maya
megap-megap
megrek-megrek
melak-melak
melambai-lambai
melambai-lambaikan
melambat-lambatkan
melaun-laun
melawak-lawak
melayap-layap
melayap-layapkan
melebih-lebihi
melebih-lebihkan
melejang-lejangkan
melengah-lengah
melihat-lihat
melimpah-limpah
melincah-lincah
meloncat-loncat
melonco-lonco
melonjak-lonjak
memacak-macak
memaki-maki
memaksa-maksa
memandai-mandai
memanggil-manggil
memanis-manis
memanjut-manjut
memasak-masak
memata-matai
mematah-matah
mematut-matut
memayah-mayahkan
membagi-bagikan
membalik-balik
membangkit-bangkit
membayang-bayangi
membayang-bayangkan
membelai-belai
membenar-benar
membenar-benari
memberai-beraikan
membesar-besarkan
membolak-balikkan
membuang-buang
membuat-buat
membunga-bungai
memburu-buru
memburu-burukan
memburuk-burukkan
memencak-mencak
memencar-mencar
memetak-metak
memetang-metangkan
memetir-metir
memikir-mikirkan
memilih-milih
meminang-minang
meminta-minta
memisah-misahkan
memontang-mantingkan
memperamat-amat
memperamat-amatkan
memperbagai-bagaikan
memperganda-gandakan
memperganduh-ganduhkan
mempermacam-macamkan
memperolok-olokkan
mempersama-samakan
mempertubi-tubi
mempertubi-tubikan
memperturut-turutkan
memuja-muja
memukang-mukang
memulun-mulun
memundi-mundi
memundi-mundikan
memuyu-muyu
menagak-nagak
menakut-nakuti
menanjur-nanjur
menanti-nanti
menari-nari
mencabik-cabik
mencabik-cabikkan
mencaing-caing
mencak-mencak
mencakup-cakup
mencapak-capak
mencari-cari
mencarik-carik
mencarut-carut
mencengis-cengis
mencepak-cepak
mencepuk-cepuk
mencerai-beraikan
mencetai-cetai
menciap-ciap
menciar-ciar
mencita-citakan
menciut-ciut
mencoang-coang
mencubit-cubit
mencuri-curi
mendecap-decap
mendengking-dengking
menderak-derakkan
menderau-derau
menderu-deru
mendesas-desuskan
mendesus-desus
mendewa-dewakan
mendudu-dudu
menebu-nebu
menegur-neguri
mengabung-ngabung
mengaci-acikan
mengada-ada
mengaduk-aduk
mengagak-agak
mengagak-agihkan
mengagut-agut
mengais-ngais
mengali-ali
mengalur-alur
mengamang-amang
mengamat-amati
mengambai-ambaikan
mengambang-ambang
mengancak-ancak
mengangan-angankan
mengangguk-angguk
mengangin-anginkan
mengangkat-angkat
mengap-mengap
mengapa-apai
mengapi-apikan
mengarah-arahi
mengata-ngatai
mengaum-aumkan
mengejan-ejan
mengelai-ngelai
mengelepik-ngelepik
mengelus-elus
mengembut-embut
mengenap-enapkan
mengenjak-enjak
mengepak-ngepak
mengepak-ngepakkan
menggaba-gabai
menggalur-galur
menggamak-gamak
menggapai-gapai
menggapai-gapaikan
menggelepar-gelepar
menggelepar-geleparkan
menggemak-gemak
menggerecak-gerecak
menggesa-gesakan
menggili-gili
menggorek-gorek
menggosok-gosok
mengguit-guit
menghalai-balaikan
menghinap-hinap
mengiang-ngiang
mengibas-ngibas
mengidam-idamkan
mengilah-ngilahkan
mengilai-ilai
mengilat-ngilatkan
mengilik-ngilik
mengimak-imak
mengiming-iming
menginjak-injak
mengipas-ngipas
mengira-ngira
mengira-ngirakan
mengiras-iras
mengiras-irasi
mengitar-ngitar
mengitik-ngitik
mengogok-ogok
mengolak-alikkan
mengoleng-oleng
mengongkang-ongkang
mengongkok-ongkok
mengonyah-anyih
mengotak-ngatikkan
mengoyak-ngoyakkan
mengoyak-oyak
menguar-nguarkan
menguar-uarkan
menguber-uber
mengubit-ubit
mengubrak-abrik
mengucar-ngacirkan
mengucek-ngucek
menguik-uik
menguis-uis
mengulit-ulit
menguman-uman
mengumbang-ambingkan
mengumpak-umpak
mengungkat-ungkat
mengungkit-ungkit
mengurik-urik
mengutak-ngatikkan
mengutik-ngutik
menimang-nimang
meningkat-ningkat
meniru-niru
meniup-niup
menjadi-jadi
menjengek-jengek
menjengit-jengit
menjilat-jilat
mentah-mentah
mentang-mentang
menunda-nunda
menusuk-nusuk
menyama-nyama
menyambar-nyambar
menyanjung-nyanjung
menyapu-nyapu
menyarat-nyarat
menyendi-nyendi
menyeret-nyeret
menyeru-nyerukan
menyia-nyiakan
menyungguh-nyungguhi
meraba-raba
merangkak-rangkak
merasa-rasai
meraung-raung
meraung-raungkan
merayau-rayau
merayu-rayu
mereka-reka
merelap-relap
meremah-remah
meremeh-temehkan
merempah-rempahi
merengek-rengek
merenik-renik
merenta-renta
merenyai-renyai
merintang-rintang
merintik-rintik
merobek-robek
meronta-ronta
merungus-rungus
merungut-rungut
mewarna-warnikan
meyakin-yakini
miju-miju
minta-minta
moga-moga
morat-marit
muda-mudi
mudah-mudahan
muka-muka
mula-mula
muluk-muluk
naga-naga
nanti-nantian
nasi-nasi
nasib-nasiban
nenek-nenek
nyolong-nyolong
ogah-ogahan
ogak-ogak
olak-alik
olak-olak
olang-aling
olang-alingan
oleh-oleh
olok-olok
olok-olokan
olong-olong
on-screen
onde-onde
one-to-one
oneng-oneng
ongkang-ongkang
ongol-ongol
onyah-anyih
orak-arik
orang-aring
orang-orangan
orok-orok
orong-orong
otak-otak
otak-otakan
padi-padian
pagi-pagi
palas-palas
paling-paling
palu-memalu
panas-panas
pandang-memandang
panji-panji
para-para
paru-paru
pasang-memasang
pasu-pasu
paya-paya
pecah-pecah
pelan-pelan
pengundang-undang
perang-perangan
perintang-rintang
perlahan-lahan
perlip-perlipan
pertama-tama
perundang-undangan
pesan-pesan
piat-piut
pick-up
pijak-pijak
pijar-pijar
pijat-pijat
pina-pina
pisang-pisang
play-off
pohon-pohonan
pokrol-pokrolan
polang-paling
poma-poma
pontang-panting
porak-parik
porak-peranda
potong-memotong
puji-pujian
pukang-pukang
pukul-memukul
pulang-pergi
pulut-pulut
pundi-pundi
punggung-memunggung
pura-pura
pusar-pusar
push-up
pusing-pusing
putus-putus
rada-rada
radio-frequency
ragu-ragu
rama-rama
rambu-rambu
rango-rango
rasa-rasanya
rata-rata
real-time
rebah-rebah
rebah-rebahan
redam-redam
reka-reka
reka-rekaan
remah-remah
remang-remang
rembah-rembih
remeh-temeh
rempah-rempah
repuh-repuh
riang-riang
ribu-ribu
rigi-rigi
robak-rabik
robat-rabit
role-play
roll-on
rombang-rambing
ruak-ruak
ruku-ruku
rumah-rumah
rumah-rumahan
rumput-rumputan
runding-merunding
runggu-rangga
runner-up
rupa-rupa
rupa-rupanya
saban-saban
sabung-menyabung
saing-menyaing
salah-salah
sama-sama
samar-samar
sambar-menyambar
sambung-bersambung
sambung-menyambung
sambut-menyambut
sampai-sampai
sandar-menyandar
sangat-sangat
sangkut-menyangkut
sapa-menyapa
sapu-sapu
sarit-sarit
satu-satu
satu-satunya
sayup-menyayup
sayup-sayup
sayur-mayur
sayur-sayuran
sci-fi
seakal-akal
seakan-akan
sealak-alak
sebaik-baiknya
sebelah-menyebelah
sebentar-sebentar
seberang-menyeberang
seboleh-bolehnya
sedalam-dalamnya
sedang-menyedang
sedap-sedapan
sedapat-dapatnya
sedikit-dikitnya
sedikit-sedikit
sedikit-sedikitnya
seelok-eloknya
segala-galanya
segan-menyegan
segan-menyegani
segan-segan
sehari-hari
sehari-harian
sejadi-jadinya
sekali-kali
sekali-sekali
sekira-kira
sekonyong-konyong
sekuasa-kuasanya
sekurang-kurangnya
sela-menyela
sela-sela
selama-lamanya
selambat-lambatnya
selang-seli
selang-seling
selar-belar
selat-latnya
selekas-lekasnya
selepas-lepas
self-esteem
self-help
sema-sema
semah-semah
semak-semak
semalam-malaman
semasa-masa
semata-mata
sembunyi-sembunyi
sembunyi-sembunyian
semena-mena
semenda-menyemenda
semengga-mengga
sementang-mentang
semu-semu
semut-semutan
sengal-sengal
sengau-sengauan
seolah-olah
sepala-pala
sepandai-pandai
sepetang-petangan
sepoi-sepoi
sepuas-puasnya
serang-menyerang
seraya-menyeraya
serba-serbi
serbah-serbih
serembah-serembih
sering-sering
serta-menyertai
serta-serta
sesal-menyesali
sesudah-sudah
sesudah-sudahnya
sesuka-suka
setempat-setempat
setengah-setengah
setidak-tidaknya
seupaya-upaya
seupaya-upayanya
sewaktu-waktu
sewenang-wenang
short-term
sia-sia
siang-siang
siapa-siapa
sibar-sibar
sibur-sibur
sida-sida
siku-siku
silah-silah
silang-menyilang
silir-semilir
sinar-seminar
sindir-menyindir
singgah-menyinggah
sorak-sorai
stand-by
stand-up
sudu-sudu
sudung-sudung
suka-suka
sulang-menyulang
sulur-suluran
sumpah-sumpah
sumpit-sumpit
sungguh-sungguh
sungut-sungut
suram-suram
surat-menyurat
suruh-suruhan
tabar-tabar
tabir-mabir
tabrak-tubruk
tabuh-tabuhan
tahu-menahu
tahu-tahu
takang-takik
take-off
takut-takut
takut-takutan
tali-bertali
tali-tali
tampak-tampak
tanam-menanam
tanam-tanaman
tanda-tanda
tangan-menangan
tangan-tangan
tanggung-menanggung
tapa-tapa
tapak-tapak
tari-menari
tari-tarian
tarik-menarik
tatah-tatah
tawak-tawak
tawang-tawang
tawar-menawar
tawar-tawar
tayum-temayum
tebu-tebu
tegak-tegak
teka-teki
temas-temas
tembak-menembak
temut-temut
tenggang-menenggang
teraba-raba
terambang-ambang
terang-terang
terang-terangan
teranggar-anggar
terangguk-angguk
teranggul-anggul
terangin-angin
terangkup-angkup
teranja-anja
terapung-apung
terayan-rayan
terayap-rayap
terbada-bada
terbahak-bahak
terbata-bata
terbatuk-batuk
terbayang-bayang
terbengkil-bengkil
terbirit-birit
terbuai-buai
terbuang-buang
terburu-buru
tercangak-cangak
tercengang-cengang
tercilap-cilap
tercongget-congget
tercungap-cungap
terdangka-dangka
terdengih-dengih
terekeh-ekeh
terembut-embut
terembut-rembut
terengah-engah
teresak-esak
tergagap-gagap
tergagau-gagau
tergaguk-gaguk
tergapai-gapai
tergegap-gegap
tergegas-gegas
tergelung-gelung
tergerenyeng-gerenyeng
tergesa-gesa
tergila-gila
tergontai-gontai
tergudik-gudik
terguling-guling
tergulut-gulut
terharak-harak
terharap-harap
terhengit-hengit
terhinggut-hinggut
terigau-igau
terincut-incut
teringa-inga
teringat-ingat
terinjak-injak
terjembak-jembak
terjerit-jerit
terkadang-kadang
terkakah-kakah
terkakak-kakak
terkanjar-kanjar
terkapah-kapah
terkapai-kapai
terkapung-kapung
terkatah-katah
terkatung-katung
terkecap-kecap
terkedek-kedek
terkedip-kedip
terkejar-kejar
terkekau-kekau
terkekeh-kekeh
terkekek-kekek
terkelinjat-kelinjat
terkelip-kelip
terkempul-kempul
terkemut-kemut
terkencar-kencar
terkepak-kepak
terkesot-kesot
terkesut-kesut
terkial-kial
terkincak-kincak
terkindap-kindap
terkinja-kinja
terkirai-kirai
terkitar-kitar
terkocoh-kocoh
terkokol-kokol
terkosel-kosel
terkoteng-koteng
terkumpal-kumpal
terlara-lara
terlayang-layang
terlebih-lebih
terlincah-lincah
terliuk-liuk
terlolong-lolong
terlongong-longong
termangu-mangu
termanja-manja
termata-mata
termengah-mengah
termimpi-mimpi
ternanti-nanti
terngiang-ngiang
teroleng-oleng
terpandang-pandang
terpecah-pecah
terpekik-pekik
terpereh-pereh
terpikau-pikau
terpinga-pinga
terpingkal-pingkal
terpontang-panting
terpusing-pusing
terputus-putus
tersanga-sanga
tersaruk-saruk
tersedan-sedan
tersedih-sedih
tersedu-sedu
tersendat-sendat
tersendeng-sendeng
tersengal-sengal
tersengguk-sengguk
tersengut-sengut
tersera-sera
terserak-serak
tersetai-setai
tersia-sia
tersipu-sipu
tersoja-soja
tersungkuk-sungkuk
tertagak-tagak
tertahan-tahan
tertatih-tatih
tertegun-tegun
tertekan-tekan
terteleng-teleng
terumbang-ambing
terumbang-umbang
terungkap-ungkap
terus-menerus
terus-terusan
think-tank
tiap-tiap
tiba-tiba
tidak-tidak
tidur-tidur
tie-dye
tiga-tiganya
tikam-menikam
tilik-menilik
timah-timah
timang-timangan
timbang-menimbang
timu-timu
tindih-bertindih
tinjau-meninjau
tip-off
tiru-tiruan
tiup-tiup
tokak-takik
tokok-menokok
tolak-menolak
tolong-menolong
top-level
trade-in
tua-tua
tuan-tuan
tuang-tuang
tuban-tuban
tukang-menukang
tukar-menukar
tulang-tulangan
tuli-tuli
tulis-menulis
tumbuh-tumbuhan
tune-up
tunggang-tunggit
tupai-tupai
turun-temurun
turut-menurut
turut-turutan
two-tone
uar-uar
ubel-ubel
ubun-ubun
ubur-ubur
uci-uci
udap-udapan
ugal-ugalan
uir-uir
ujar-ujar
ukir-mengukir
ula-ula
ulak-ulak
ulang-alik
ulang-aling
ulang-ulang
ulap-ulap
ular-ular
ular-ularan
ulung-ulung
umang-umang
umbang-ambing
umbi-umbian
umbul-umbul
umbut-umbut
uncang-uncit
undak-undakan
undang-undang
unduk-unduk
undung-undung
undur-undur
unggat-unggit
ungkit-ungkit
unting-unting
untung-untung
untung-untungan
upside-down
ura-ura
uran-uran
urat-urat
uring-uringan
urup-urup
urup-urupan
urus-urus
user-user
user-useran
utar-utar
voice-over
walk-out
wangi-wangian
wanti-wanti
wara-wara
warna-warni
water-cooled
world-class
yang-yang
""".split()
)
